[Libreoffice-commits] core.git: sw/source
Miklos Vajna
vmiklos at suse.cz
Sat Feb 9 03:07:30 PST 2013
sw/source/core/doc/notxtfrm.cxx | 10 -
sw/source/core/docnode/ndsect.cxx | 2
sw/source/core/inc/frame.hxx | 296 ++++++++++++++++++-------------------
sw/source/core/inc/ftnfrm.hxx | 4
sw/source/core/inc/layfrm.hxx | 4
sw/source/core/inc/sectfrm.hxx | 4
sw/source/core/layout/calcmove.cxx | 174 ++++++++++-----------
sw/source/core/layout/colfrm.cxx | 2
sw/source/core/layout/findfrm.cxx | 42 ++---
sw/source/core/layout/flowfrm.cxx | 26 +--
sw/source/core/layout/fly.cxx | 106 ++++++-------
sw/source/core/layout/flycnt.cxx | 4
sw/source/core/layout/flyincnt.cxx | 24 +--
sw/source/core/layout/flylay.cxx | 34 ++--
sw/source/core/layout/frmtool.cxx | 26 +--
sw/source/core/layout/ftnfrm.cxx | 14 -
sw/source/core/layout/hffrm.cxx | 56 +++----
sw/source/core/layout/newfrm.cxx | 4
sw/source/core/layout/pagechg.cxx | 54 +++---
sw/source/core/layout/sectfrm.cxx | 36 ++--
sw/source/core/layout/ssfrm.cxx | 56 +++----
sw/source/core/layout/tabfrm.cxx | 90 +++++------
sw/source/core/layout/wsfrm.cxx | 246 +++++++++++++++---------------
sw/source/core/text/frmform.cxx | 2
sw/source/core/text/txtfrm.cxx | 4
25 files changed, 660 insertions(+), 660 deletions(-)
New commits:
commit 13003431bface864af739188b1a76a6b9177a1fe
Author: Miklos Vajna <vmiklos at suse.cz>
Date: Sat Feb 9 11:35:20 2013 +0100
SwFrm: rename member variables missing their prefix
Change-Id: I88e7abb29e18859ae4fdce5a613e6d233f9d27a1
diff --git a/sw/source/core/doc/notxtfrm.cxx b/sw/source/core/doc/notxtfrm.cxx
index 137ade3..0d89707 100644
--- a/sw/source/core/doc/notxtfrm.cxx
+++ b/sw/source/core/doc/notxtfrm.cxx
@@ -156,7 +156,7 @@ SwNoTxtFrm::SwNoTxtFrm(SwNoTxtNode * const pNode, SwFrm* pSib )
void SwNoTxtFrm::InitCtor()
{
- nType = FRMC_NOTXT;
+ mnType = FRMC_NOTXT;
// The graphic's weight is 0 if it has not been read,
// < 0 if we had a read error and we needed to use the replacement and
// > 0 if it is available
@@ -516,17 +516,17 @@ void SwNoTxtFrm::MakeAll()
SwBorderAttrAccess aAccess( SwFrm::GetCache(), this );
const SwBorderAttrs &rAttrs = *aAccess.Get();
- while ( !bValidPos || !bValidSize || !bValidPrtArea )
+ while ( !mbValidPos || !mbValidSize || !mbValidPrtArea )
{
MakePos();
- if ( !bValidSize )
+ if ( !mbValidSize )
Frm().Width( GetUpper()->Prt().Width() );
MakePrtArea( rAttrs );
- if ( !bValidSize )
- { bValidSize = sal_True;
+ if ( !mbValidSize )
+ { mbValidSize = sal_True;
Format();
}
}
diff --git a/sw/source/core/docnode/ndsect.cxx b/sw/source/core/docnode/ndsect.cxx
index 7ea4f7e..5610c40 100644
--- a/sw/source/core/docnode/ndsect.cxx
+++ b/sw/source/core/docnode/ndsect.cxx
@@ -1020,7 +1020,7 @@ SwFrm* SwClearDummies( SwFrm* pFrm )
else
pFrm = pTmp;
if( pTmp )
- pTmp->pPrev = pSectFrm->GetPrev();
+ pTmp->mpPrev = pSectFrm->GetPrev();
delete pSectFrm;
}
}
diff --git a/sw/source/core/inc/frame.hxx b/sw/source/core/inc/frame.hxx
index febaa8d..f93ae67 100644
--- a/sw/source/core/inc/frame.hxx
+++ b/sw/source/core/inc/frame.hxx
@@ -87,8 +87,8 @@ typedef struct _xmlTextWriter *xmlTextWriterPtr;
#define FRM_FTNBOSS 0x0006
#define FRM_ACCESSIBLE (FRM_HEADER|FRM_FOOTER|FRM_FTN|FRM_TXT|FRM_ROOT|FRM_FLY|FRM_TAB|FRM_CELL|FRM_PAGE)
-// The type of the frame is internal represented by the 4-bit value nType,
-// which can expanded to the types above by shifting a bit (0x1 << nType)
+// The type of the frame is internal represented by the 4-bit value mnType,
+// which can expanded to the types above by shifting a bit (0x1 << mnType)
// Here are the corresponding defines for the compressed representation:
#define FRMC_ROOT 0
#define FRMC_PAGE 1
@@ -250,7 +250,7 @@ class SwFrm: public SwClient, public SfxBroadcaster
friend void MakeNxt( SwFrm *pFrm, SwFrm *pNxt );
// cache for (border) attributes
- static SwCache *pCache;
+ static SwCache *mpCache;
// #i65250#
// frame ID is now in general available - used for layout loop control
@@ -258,9 +258,9 @@ class SwFrm: public SwClient, public SfxBroadcaster
const sal_uInt32 mnFrmId;
SwRootFrm *mpRoot;
- SwLayoutFrm *pUpper;
- SwFrm *pNext;
- SwFrm *pPrev;
+ SwLayoutFrm *mpUpper;
+ SwFrm *mpNext;
+ SwFrm *mpPrev;
SwFrm *_FindNext();
SwFrm *_FindPrev();
@@ -330,47 +330,47 @@ class SwFrm: public SwClient, public SfxBroadcaster
const SwLayoutFrm* ImplGetNextLayoutLeaf( bool bFwd ) const;
protected:
- SwSortedObjs* pDrawObjs; // draw objects, can be 0
+ SwSortedObjs* mpDrawObjs; // draw objects, can be 0
- SwRect aFrm; // absolute position in document and size of the Frm
- SwRect aPrt; // position relatively to Frm and size of PrtArea
+ SwRect maFrm; // absolute position in document and size of the Frm
+ SwRect maPrt; // position relatively to Frm and size of PrtArea
- sal_uInt16 bReverse : 1; // Next line above/at the right side instead
+ sal_uInt16 mbReverse : 1; // Next line above/at the right side instead
// under/at the left side of the previous line
- sal_uInt16 bInvalidR2L : 1;
- sal_uInt16 bDerivedR2L : 1;
- sal_uInt16 bRightToLeft : 1;
- sal_uInt16 bInvalidVert : 1;
- sal_uInt16 bDerivedVert : 1;
- sal_uInt16 bVertical : 1;
+ sal_uInt16 mbInvalidR2L : 1;
+ sal_uInt16 mbDerivedR2L : 1;
+ sal_uInt16 mbRightToLeft : 1;
+ sal_uInt16 mbInvalidVert : 1;
+ sal_uInt16 mbDerivedVert : 1;
+ sal_uInt16 mbVertical : 1;
// Support for Classical Mongolian Script (SCMS) joint with Jiayanmin
- sal_uInt16 bVertLR : 1;
- sal_uInt16 nType : 4; //Who am I?
-
- sal_Bool bValidPos : 1;
- sal_Bool bValidPrtArea : 1;
- sal_Bool bValidSize : 1;
- sal_Bool bValidLineNum : 1;
- sal_Bool bFixSize : 1;
- sal_Bool bUnUsed1 : 1;
+ sal_uInt16 mbVertLR : 1;
+ sal_uInt16 mnType : 4; //Who am I?
+
+ sal_Bool mbValidPos : 1;
+ sal_Bool mbValidPrtArea : 1;
+ sal_Bool mbValidSize : 1;
+ sal_Bool mbValidLineNum : 1;
+ sal_Bool mbFixSize : 1;
+ sal_Bool mbUnUsed1 : 1;
// if sal_True, frame will be painted completely even content was changed
// only partially. For CntntFrms a border (from Action) will exclusively
- // painted if <bCompletePaint> is sal_True.
- sal_Bool bCompletePaint : 1;
- sal_Bool bRetouche : 1; // frame is responsible for retouching
+ // painted if <mbCompletePaint> is sal_True.
+ sal_Bool mbCompletePaint : 1;
+ sal_Bool mbRetouche : 1; // frame is responsible for retouching
protected:
- sal_Bool bInfInvalid : 1; // InfoFlags are invalid
- sal_Bool bInfBody : 1; // Frm is in document body
- sal_Bool bInfTab : 1; // Frm is in a table
- sal_Bool bInfFly : 1; // Frm is in a Fly
- sal_Bool bInfFtn : 1; // Frm is in a footnote
- sal_Bool bInfSct : 1; // Frm is in a section
- sal_Bool bColLocked : 1; // lock Grow/Shrink for column-wise section
+ sal_Bool mbInfInvalid : 1; // InfoFlags are invalid
+ sal_Bool mbInfBody : 1; // Frm is in document body
+ sal_Bool mbInfTab : 1; // Frm is in a table
+ sal_Bool mbInfFly : 1; // Frm is in a Fly
+ sal_Bool mbInfFtn : 1; // Frm is in a footnote
+ sal_Bool mbInfSct : 1; // Frm is in a section
+ sal_Bool mbColLocked : 1; // lock Grow/Shrink for column-wise section
// or fly frames, will be set in Format
- void ColLock() { bColLocked = sal_True; }
- void ColUnlock() { bColLocked = sal_False; }
+ void ColLock() { mbColLocked = sal_True; }
+ void ColUnlock() { mbColLocked = sal_False; }
void Destroy(); // for ~SwRootFrm
@@ -431,11 +431,11 @@ protected:
public:
TYPEINFO(); // already in base class
- sal_uInt16 GetType() const { return 0x1 << nType; }
+ sal_uInt16 GetType() const { return 0x1 << mnType; }
- static SwCache &GetCache() { return *pCache; }
- static SwCache *GetCachePtr() { return pCache; }
- static void SetCache( SwCache *pNew ) { pCache = pNew; }
+ static SwCache &GetCache() { return *mpCache; }
+ static SwCache *GetCachePtr() { return mpCache; }
+ static void SetCache( SwCache *pNew ) { mpCache = pNew; }
// change PrtArea size and FrmSize
SwTwips Shrink( SwTwips, sal_Bool bTst = sal_False, sal_Bool bInfo = sal_False );
@@ -443,9 +443,9 @@ public:
// different methods for inserting in layout tree (for performance reasons)
- // insert before pBehind or at the end of the chain below pUpper
+ // insert before pBehind or at the end of the chain below mpUpper
void InsertBefore( SwLayoutFrm* pParent, SwFrm* pBehind );
- // insert after pBefore or at the beginnig of the chain below pUpper
+ // insert after pBefore or at the beginnig of the chain below mpUpper
void InsertBehind( SwLayoutFrm *pParent, SwFrm *pBefore );
// insert before pBehind or at the end of the chain while considering
// the siblings of pSct
@@ -476,8 +476,8 @@ public:
// work with chain of FlyFrms
void AppendFly( SwFlyFrm *pNew );
void RemoveFly( SwFlyFrm *pToRemove );
- const SwSortedObjs *GetDrawObjs() const { return pDrawObjs; }
- SwSortedObjs *GetDrawObjs() { return pDrawObjs; }
+ const SwSortedObjs *GetDrawObjs() const { return mpDrawObjs; }
+ SwSortedObjs *GetDrawObjs() { return mpDrawObjs; }
// #i28701# - change purpose of method and adjust its name
void InvalidateObjs( const bool _bInvaPosOnly,
const bool _bNoInvaOfAsCharAnchoredObjs = true );
@@ -511,14 +511,14 @@ public:
inline void SetCompletePaint() const;
inline void ResetCompletePaint() const;
- inline sal_Bool IsCompletePaint() const { return bCompletePaint; }
+ inline sal_Bool IsCompletePaint() const { return mbCompletePaint; }
inline void SetRetouche() const;
inline void ResetRetouche() const;
- inline sal_Bool IsRetouche() const { return bRetouche; }
+ inline sal_Bool IsRetouche() const { return mbRetouche; }
void SetInfFlags();
- inline void InvalidateInfFlags() { bInfInvalid = sal_True; }
+ inline void InvalidateInfFlags() { mbInfInvalid = sal_True; }
inline bool IsInDocBody() const; // use InfoFlags, determine flags
inline sal_Bool IsInFtn() const; // if necessary
inline sal_Bool IsInTab() const;
@@ -535,22 +535,22 @@ public:
bool IsInBalancedSection() const;
- inline sal_Bool IsReverse() const { return bReverse; }
- inline void SetReverse( sal_Bool bNew ){ bReverse = bNew ? 1 : 0; }
+ inline sal_Bool IsReverse() const { return mbReverse; }
+ inline void SetReverse( sal_Bool bNew ){ mbReverse = bNew ? 1 : 0; }
inline sal_Bool IsVertical() const;
//Support for Classical Mongolian Script (SCMS) joint with Jiayanmin
inline sal_Bool IsVertLR() const;
inline sal_Bool GetVerticalFlag() const;
- inline void SetVertical( sal_Bool bNew ){ bVertical = bNew ? 1 : 0; }
+ inline void SetVertical( sal_Bool bNew ){ mbVertical = bNew ? 1 : 0; }
//Support for Classical Mongolian Script (SCMS) joint with Jiayanmin
- inline void SetbVertLR( sal_Bool bNew ) { bVertLR = bNew ? 1 : 0; }
- inline void SetDerivedVert( sal_Bool bNew ){ bDerivedVert = bNew ? 1 : 0; }
- inline void SetInvalidVert( sal_Bool bNew) { bInvalidVert = bNew ? 1 : 0; }
+ inline void SetbVertLR( sal_Bool bNew ) { mbVertLR = bNew ? 1 : 0; }
+ inline void SetDerivedVert( sal_Bool bNew ){ mbDerivedVert = bNew ? 1 : 0; }
+ inline void SetInvalidVert( sal_Bool bNew) { mbInvalidVert = bNew ? 1 : 0; }
inline sal_Bool IsRightToLeft() const;
inline sal_Bool GetRightToLeftFlag() const;
- inline void SetRightToLeft( sal_Bool bNew ){ bRightToLeft = bNew ? 1 : 0; }
- inline void SetDerivedR2L( sal_Bool bNew ) { bDerivedR2L = bNew ? 1 : 0; }
- inline void SetInvalidR2L( sal_Bool bNew ) { bInvalidR2L = bNew ? 1 : 0; }
+ inline void SetRightToLeft( sal_Bool bNew ){ mbRightToLeft = bNew ? 1 : 0; }
+ inline void SetDerivedR2L( sal_Bool bNew ) { mbDerivedR2L = bNew ? 1 : 0; }
+ inline void SetInvalidR2L( sal_Bool bNew ) { mbInvalidR2L = bNew ? 1 : 0; }
void CheckDirChange();
// returns upper left frame position for LTR and
@@ -584,16 +584,16 @@ public:
const SwAttrSet *GetAttrSet() const;
- inline sal_Bool HasFixSize() const { return bFixSize; }
- inline void SetFixSize( sal_Bool bNew ) { bFixSize = bNew; }
+ inline sal_Bool HasFixSize() const { return mbFixSize; }
+ inline void SetFixSize( sal_Bool bNew ) { mbFixSize = bNew; }
// check all pages (starting from the given) and correct them if needed
static void CheckPageDescs( SwPageFrm *pStart, sal_Bool bNotifyFields = sal_True );
// might return 0, with and without const
- SwFrm *GetNext() { return pNext; }
- SwFrm *GetPrev() { return pPrev; }
- SwLayoutFrm *GetUpper() { return pUpper; }
+ SwFrm *GetNext() { return mpNext; }
+ SwFrm *GetPrev() { return mpPrev; }
+ SwLayoutFrm *GetUpper() { return mpUpper; }
SwRootFrm *getRootFrm(){ return mpRoot; }
SwPageFrm *FindPageFrm();
SwFrm *FindColFrm();
@@ -605,9 +605,9 @@ public:
SwSectionFrm *ImplFindSctFrm();
SwFrm *FindFooterOrHeader();
SwFrm *GetLower();
- const SwFrm *GetNext() const { return pNext; }
- const SwFrm *GetPrev() const { return pPrev; }
- const SwLayoutFrm *GetUpper() const { return pUpper; }
+ const SwFrm *GetNext() const { return mpNext; }
+ const SwFrm *GetPrev() const { return mpPrev; }
+ const SwLayoutFrm *GetUpper() const { return mpUpper; }
const SwRootFrm *getRootFrm() const { return mpRoot; }
inline SwTabFrm *FindTabFrm();
inline SwFtnFrm *FindFtnFrm();
@@ -656,10 +656,10 @@ public:
// #i79774#
SwFrm* _GetIndPrev() const;
SwFrm* GetIndPrev() const
- { return ( pPrev || !IsInSct() ) ? pPrev : _GetIndPrev(); }
+ { return ( mpPrev || !IsInSct() ) ? mpPrev : _GetIndPrev(); }
SwFrm* GetIndNext()
- { return ( pNext || !IsInSct() ) ? pNext : _GetIndNext(); }
+ { return ( mpNext || !IsInSct() ) ? mpNext : _GetIndNext(); }
const SwFrm* GetIndNext() const { return ((SwFrm*)this)->GetIndNext(); }
sal_uInt16 GetPhyPageNum() const; // page number without offset
@@ -678,8 +678,8 @@ public:
// the predecessors are already formatted
inline Point GetRelPos() const;
- const SwRect &Frm() const { return aFrm; }
- const SwRect &Prt() const { return aPrt; }
+ const SwRect &Frm() const { return maFrm; }
+ const SwRect &Prt() const { return maPrt; }
// PaintArea is the area where content might be displayed.
// The margin of a page or the space between columns belongs to it.
@@ -692,21 +692,21 @@ public:
// This should not delude into changing those value randomly; it is the
// only option to circumvent compiler problems (same method with public
// and protected).
- SwRect &Frm() { return aFrm; }
- SwRect &Prt() { return aPrt; }
+ SwRect &Frm() { return maFrm; }
+ SwRect &Prt() { return maPrt; }
virtual Size ChgSize( const Size& aNewSize );
virtual void Cut() = 0;
virtual void Paste( SwFrm* pParent, SwFrm* pSibling = 0 ) = 0;
- void ValidateLineNum() { bValidLineNum = sal_True; }
+ void ValidateLineNum() { mbValidLineNum = sal_True; }
- sal_Bool GetValidPosFlag() const { return bValidPos; }
- sal_Bool GetValidPrtAreaFlag()const { return bValidPrtArea; }
- sal_Bool GetValidSizeFlag() const { return bValidSize; }
- sal_Bool GetValidLineNumFlag()const { return bValidLineNum; }
- sal_Bool IsValid() const { return bValidPos && bValidSize && bValidPrtArea; }
+ sal_Bool GetValidPosFlag() const { return mbValidPos; }
+ sal_Bool GetValidPrtAreaFlag()const { return mbValidPrtArea; }
+ sal_Bool GetValidSizeFlag() const { return mbValidSize; }
+ sal_Bool GetValidLineNumFlag()const { return mbValidLineNum; }
+ sal_Bool IsValid() const { return mbValidPos && mbValidSize && mbValidPrtArea; }
// Only invalidate Frm
// #i28701# - add call to method <_ActionOnInvalidation(..)>
@@ -717,42 +717,42 @@ public:
// invalidate.
void _InvalidateSize()
{
- if ( bValidSize && _InvalidationAllowed( INVALID_SIZE ) )
+ if ( mbValidSize && _InvalidationAllowed( INVALID_SIZE ) )
{
- bValidSize = sal_False;
+ mbValidSize = sal_False;
_ActionOnInvalidation( INVALID_SIZE );
}
}
void _InvalidatePrt()
{
- if ( bValidPrtArea && _InvalidationAllowed( INVALID_PRTAREA ) )
+ if ( mbValidPrtArea && _InvalidationAllowed( INVALID_PRTAREA ) )
{
- bValidPrtArea = sal_False;
+ mbValidPrtArea = sal_False;
_ActionOnInvalidation( INVALID_PRTAREA );
}
}
void _InvalidatePos()
{
- if ( bValidPos && _InvalidationAllowed( INVALID_POS ) )
+ if ( mbValidPos && _InvalidationAllowed( INVALID_POS ) )
{
- bValidPos = sal_False;
+ mbValidPos = sal_False;
_ActionOnInvalidation( INVALID_POS );
}
}
void _InvalidateLineNum()
{
- if ( bValidLineNum && _InvalidationAllowed( INVALID_LINENUM ) )
+ if ( mbValidLineNum && _InvalidationAllowed( INVALID_LINENUM ) )
{
- bValidLineNum = sal_False;
+ mbValidLineNum = sal_False;
_ActionOnInvalidation( INVALID_LINENUM );
}
}
void _InvalidateAll()
{
- if ( ( bValidSize || bValidPrtArea || bValidPos ) &&
+ if ( ( mbValidSize || mbValidPrtArea || mbValidPos ) &&
_InvalidationAllowed( INVALID_ALL ) )
{
- bValidSize = bValidPrtArea = bValidPos = sal_False;
+ mbValidSize = mbValidPrtArea = mbValidPos = sal_False;
_ActionOnInvalidation( INVALID_ALL );
}
}
@@ -827,7 +827,7 @@ public:
// Fly in ... and footnotes
sal_Bool IsProtected() const;
- sal_Bool IsColLocked() const { return bColLocked; }
+ sal_Bool IsColLocked() const { return mbColLocked; }
virtual ~SwFrm();
@@ -886,77 +886,77 @@ public:
inline bool SwFrm::IsInDocBody() const
{
- if ( bInfInvalid )
+ if ( mbInfInvalid )
((SwFrm*)this)->SetInfFlags();
- return bInfBody;
+ return mbInfBody;
}
inline sal_Bool SwFrm::IsInFtn() const
{
- if ( bInfInvalid )
+ if ( mbInfInvalid )
((SwFrm*)this)->SetInfFlags();
- return bInfFtn;
+ return mbInfFtn;
}
inline sal_Bool SwFrm::IsInTab() const
{
- if ( bInfInvalid )
+ if ( mbInfInvalid )
((SwFrm*)this)->SetInfFlags();
- return bInfTab;
+ return mbInfTab;
}
inline sal_Bool SwFrm::IsInFly() const
{
- if ( bInfInvalid )
+ if ( mbInfInvalid )
((SwFrm*)this)->SetInfFlags();
- return bInfFly;
+ return mbInfFly;
}
inline sal_Bool SwFrm::IsInSct() const
{
- if ( bInfInvalid )
+ if ( mbInfInvalid )
((SwFrm*)this)->SetInfFlags();
- return bInfSct;
+ return mbInfSct;
}
sal_Bool SwFrm::IsVertical() const
{
- if( bInvalidVert )
+ if( mbInvalidVert )
((SwFrm*)this)->SetDirFlags( sal_True );
- return bVertical != 0;
+ return mbVertical != 0;
}
//Support for Classical Mongolian Script (SCMS) joint with Jiayanmin
inline sal_Bool SwFrm::IsVertLR() const
{
- return bVertLR != 0;
+ return mbVertLR != 0;
}
//End of SCMS
sal_Bool SwFrm::GetVerticalFlag() const
{
- return bVertical != 0;
+ return mbVertical != 0;
}
inline sal_Bool SwFrm::IsRightToLeft() const
{
- if( bInvalidR2L )
+ if( mbInvalidR2L )
((SwFrm*)this)->SetDirFlags( sal_False );
- return bRightToLeft != 0;
+ return mbRightToLeft != 0;
}
sal_Bool SwFrm::GetRightToLeftFlag() const
{
- return bRightToLeft != 0;
+ return mbRightToLeft != 0;
}
inline void SwFrm::SetCompletePaint() const
{
- ((SwFrm*)this)->bCompletePaint = sal_True;
+ ((SwFrm*)this)->mbCompletePaint = sal_True;
}
inline void SwFrm::ResetCompletePaint() const
{
- ((SwFrm*)this)->bCompletePaint = sal_False;
+ ((SwFrm*)this)->mbCompletePaint = sal_False;
}
inline void SwFrm::SetRetouche() const
{
- ((SwFrm*)this)->bRetouche = sal_True;
+ ((SwFrm*)this)->mbRetouche = sal_True;
}
inline void SwFrm::ResetRetouche() const
{
- ((SwFrm*)this)->bRetouche = sal_False;
+ ((SwFrm*)this)->mbRetouche = sal_False;
}
inline SwLayoutFrm *SwFrm::GetNextLayoutLeaf()
@@ -978,31 +978,31 @@ inline const SwLayoutFrm *SwFrm::GetPrevLayoutLeaf() const
inline void SwFrm::InvalidateSize()
{
- if ( bValidSize )
+ if ( mbValidSize )
ImplInvalidateSize();
}
inline void SwFrm::InvalidatePrt()
{
- if ( bValidPrtArea )
+ if ( mbValidPrtArea )
ImplInvalidatePrt();
}
inline void SwFrm::InvalidatePos()
{
- if ( bValidPos )
+ if ( mbValidPos )
ImplInvalidatePos();
}
inline void SwFrm::InvalidateLineNum()
{
- if ( bValidLineNum )
+ if ( mbValidLineNum )
ImplInvalidateLineNum();
}
inline void SwFrm::InvalidateAll()
{
if ( _InvalidationAllowed( INVALID_ALL ) )
{
- if ( bValidPrtArea && bValidSize && bValidPos )
+ if ( mbValidPrtArea && mbValidSize && mbValidPos )
ImplInvalidatePos();
- bValidPrtArea = bValidSize = bValidPos = sal_False;
+ mbValidPrtArea = mbValidSize = mbValidPos = sal_False;
// #i28701#
_ActionOnInvalidation( INVALID_ALL );
@@ -1010,31 +1010,31 @@ inline void SwFrm::InvalidateAll()
}
inline void SwFrm::InvalidateNextPos( sal_Bool bNoFtn )
{
- if ( pNext && !pNext->IsSctFrm() )
- pNext->InvalidatePos();
+ if ( mpNext && !mpNext->IsSctFrm() )
+ mpNext->InvalidatePos();
#ifndef C30 // maybe it works for C40?
else
ImplInvalidateNextPos( bNoFtn );
#else
- if ( !pNext )
+ if ( !mpNext )
ImplInvalidateNextPos( bNoFtn );
#endif
}
inline void SwFrm::Calc() const
{
- if ( !bValidPos || !bValidPrtArea || !bValidSize )
+ if ( !mbValidPos || !mbValidPrtArea || !mbValidSize )
((SwFrm*)this)->PrepareMake();
}
inline void SwFrm::OptCalc() const
{
- if ( !bValidPos || !bValidPrtArea || !bValidSize )
+ if ( !mbValidPos || !mbValidPrtArea || !mbValidSize )
((SwFrm*)this)->OptPrepareMake();
}
inline Point SwFrm::GetRelPos() const
{
- Point aRet( aFrm.Pos() );
+ Point aRet( maFrm.Pos() );
// here we cast since SwLayoutFrm is declared only as forwarded
aRet -= ((SwFrm*)GetUpper())->Prt().Pos();
aRet -= ((SwFrm*)GetUpper())->Frm().Pos();
@@ -1092,45 +1092,45 @@ inline const SwSectionFrm *SwFrm::FindSctFrm() const
}
inline SwFrm *SwFrm::FindNext()
{
- if ( pNext )
- return pNext;
+ if ( mpNext )
+ return mpNext;
else
return _FindNext();
}
inline const SwFrm *SwFrm::FindNext() const
{
- if ( pNext )
- return pNext;
+ if ( mpNext )
+ return mpNext;
else
return ((SwFrm*)this)->_FindNext();
}
// #i27138# - add parameter <_bInSameFtn>
inline SwCntntFrm *SwFrm::FindNextCnt( const bool _bInSameFtn )
{
- if ( pNext && pNext->IsCntntFrm() )
- return (SwCntntFrm*)pNext;
+ if ( mpNext && mpNext->IsCntntFrm() )
+ return (SwCntntFrm*)mpNext;
else
return _FindNextCnt( _bInSameFtn );
}
// #i27138# - add parameter <_bInSameFtn>
inline const SwCntntFrm *SwFrm::FindNextCnt( const bool _bInSameFtn ) const
{
- if ( pNext && pNext->IsCntntFrm() )
- return (SwCntntFrm*)pNext;
+ if ( mpNext && mpNext->IsCntntFrm() )
+ return (SwCntntFrm*)mpNext;
else
return ((SwFrm*)this)->_FindNextCnt( _bInSameFtn );
}
inline SwFrm *SwFrm::FindPrev()
{
- if ( pPrev && !pPrev->IsSctFrm() )
- return pPrev;
+ if ( mpPrev && !mpPrev->IsSctFrm() )
+ return mpPrev;
else
return _FindPrev();
}
inline const SwFrm *SwFrm::FindPrev() const
{
- if ( pPrev && !pPrev->IsSctFrm() )
- return pPrev;
+ if ( mpPrev && !mpPrev->IsSctFrm() )
+ return mpPrev;
else
return ((SwFrm*)this)->_FindPrev();
}
@@ -1142,15 +1142,15 @@ inline bool SwFrm::IsLayoutFrm() const
}
inline bool SwFrm::IsRootFrm() const
{
- return nType == FRMC_ROOT;
+ return mnType == FRMC_ROOT;
}
inline bool SwFrm::IsPageFrm() const
{
- return nType == FRMC_PAGE;
+ return mnType == FRMC_PAGE;
}
inline bool SwFrm::IsColumnFrm() const
{
- return nType == FRMC_COLUMN;
+ return mnType == FRMC_COLUMN;
}
inline bool SwFrm::IsFtnBossFrm() const
{
@@ -1158,43 +1158,43 @@ inline bool SwFrm::IsFtnBossFrm() const
}
inline bool SwFrm::IsHeaderFrm() const
{
- return nType == FRMC_HEADER;
+ return mnType == FRMC_HEADER;
}
inline bool SwFrm::IsFooterFrm() const
{
- return nType == FRMC_FOOTER;
+ return mnType == FRMC_FOOTER;
}
inline bool SwFrm::IsFtnContFrm() const
{
- return nType == FRMC_FTNCONT;
+ return mnType == FRMC_FTNCONT;
}
inline bool SwFrm::IsFtnFrm() const
{
- return nType == FRMC_FTN;
+ return mnType == FRMC_FTN;
}
inline bool SwFrm::IsBodyFrm() const
{
- return nType == FRMC_BODY;
+ return mnType == FRMC_BODY;
}
inline bool SwFrm::IsFlyFrm() const
{
- return nType == FRMC_FLY;
+ return mnType == FRMC_FLY;
}
inline bool SwFrm::IsSctFrm() const
{
- return nType == FRMC_SECTION;
+ return mnType == FRMC_SECTION;
}
inline bool SwFrm::IsTabFrm() const
{
- return nType == FRMC_TAB;
+ return mnType == FRMC_TAB;
}
inline bool SwFrm::IsRowFrm() const
{
- return nType == FRMC_ROW;
+ return mnType == FRMC_ROW;
}
inline bool SwFrm::IsCellFrm() const
{
- return nType == FRMC_CELL;
+ return mnType == FRMC_CELL;
}
inline bool SwFrm::IsCntntFrm() const
{
@@ -1202,11 +1202,11 @@ inline bool SwFrm::IsCntntFrm() const
}
inline bool SwFrm::IsTxtFrm() const
{
- return nType == FRMC_TXT;
+ return mnType == FRMC_TXT;
}
inline bool SwFrm::IsNoTxtFrm() const
{
- return nType == FRMC_NOTXT;
+ return mnType == FRMC_NOTXT;
}
inline bool SwFrm::IsFlowFrm() const
{
diff --git a/sw/source/core/inc/ftnfrm.hxx b/sw/source/core/inc/ftnfrm.hxx
index 42a5ed6..ebd1b09 100644
--- a/sw/source/core/inc/ftnfrm.hxx
+++ b/sw/source/core/inc/ftnfrm.hxx
@@ -108,8 +108,8 @@ public:
sal_Bool IsBackMoveLocked() { return bBackMoveLocked; }
// prevents that the last content deletes the SwFtnFrm as well (Cut())
- inline void ColLock() { bColLocked = sal_True; }
- inline void ColUnlock() { bColLocked = sal_False; }
+ inline void ColLock() { mbColLocked = sal_True; }
+ inline void ColUnlock() { mbColLocked = sal_False; }
// #i49383#
inline void UnlockPosOfLowerObjs()
diff --git a/sw/source/core/inc/layfrm.hxx b/sw/source/core/inc/layfrm.hxx
index 5f267d7..fdd6b7c 100644
--- a/sw/source/core/inc/layfrm.hxx
+++ b/sw/source/core/inc/layfrm.hxx
@@ -185,12 +185,12 @@ inline SwFrm* SwLayoutFrm::ContainsAny( const bool _bInvestigateFtnForSections )
// Diese SwFrm-inlines sind hier, damit frame.hxx nicht layfrm.hxx includen muss
inline bool SwFrm::IsColBodyFrm() const
{
- return nType == FRMC_BODY && GetUpper()->IsColumnFrm();
+ return mnType == FRMC_BODY && GetUpper()->IsColumnFrm();
}
inline bool SwFrm::IsPageBodyFrm() const
{
- return nType == FRMC_BODY && GetUpper()->IsPageFrm();
+ return mnType == FRMC_BODY && GetUpper()->IsPageFrm();
}
inline SwFrm* SwLayoutFrm::GetLastLower()
diff --git a/sw/source/core/inc/sectfrm.hxx b/sw/source/core/inc/sectfrm.hxx
index 5f97dd4..0d513b1 100644
--- a/sw/source/core/inc/sectfrm.hxx
+++ b/sw/source/core/inc/sectfrm.hxx
@@ -81,8 +81,8 @@ public:
inline const SwCntntFrm *FindLastCntnt( sal_uInt8 nMode = 0 ) const;
inline SwSection* GetSection() { return pSection; }
inline const SwSection* GetSection() const { return pSection; }
- inline void ColLock() { bColLocked = sal_True; }
- inline void ColUnlock() { bColLocked = sal_False; }
+ inline void ColLock() { mbColLocked = sal_True; }
+ inline void ColUnlock() { mbColLocked = sal_False; }
void CalcFtnCntnt();
void SimpleFormat();
diff --git a/sw/source/core/layout/calcmove.cxx b/sw/source/core/layout/calcmove.cxx
index f4a2c3a..0316791 100644
--- a/sw/source/core/layout/calcmove.cxx
+++ b/sw/source/core/layout/calcmove.cxx
@@ -505,9 +505,9 @@ static SwFrm* lcl_NotHiddenPrev( SwFrm* pFrm )
void SwFrm::MakePos()
{
- if ( !bValidPos )
+ if ( !mbValidPos )
{
- bValidPos = sal_True;
+ mbValidPos = sal_True;
bool bUseUpper = false;
SwFrm* pPrv = lcl_Prev( this );
if ( pPrv &&
@@ -534,36 +534,36 @@ void SwFrm::MakePos()
SWRECTFN( ( IsCellFrm() && GetUpper() ? GetUpper() : this ) )
if ( !bUseUpper && pPrv )
{
- aFrm.Pos( pPrv->Frm().Pos() );
+ maFrm.Pos( pPrv->Frm().Pos() );
if( FRM_NEIGHBOUR & nMyType )
{
sal_Bool bR2L = IsRightToLeft();
if( bR2L )
- (aFrm.*fnRect->fnSetPosX)( (aFrm.*fnRect->fnGetLeft)() -
- (aFrm.*fnRect->fnGetWidth)() );
+ (maFrm.*fnRect->fnSetPosX)( (maFrm.*fnRect->fnGetLeft)() -
+ (maFrm.*fnRect->fnGetWidth)() );
else
- (aFrm.*fnRect->fnSetPosX)( (aFrm.*fnRect->fnGetLeft)() +
+ (maFrm.*fnRect->fnSetPosX)( (maFrm.*fnRect->fnGetLeft)() +
(pPrv->Frm().*fnRect->fnGetWidth)() );
// cells may now leave their uppers
- if( bVert && FRM_CELL & nMyType && !bReverse )
- aFrm.Pos().X() -= aFrm.Width() -pPrv->Frm().Width();
+ if( bVert && FRM_CELL & nMyType && !mbReverse )
+ maFrm.Pos().X() -= maFrm.Width() -pPrv->Frm().Width();
}
else if( bVert && FRM_NOTE_VERT & nMyType )
{
- if( bReverse )
- aFrm.Pos().X() += pPrv->Frm().Width();
+ if( mbReverse )
+ maFrm.Pos().X() += pPrv->Frm().Width();
else
//Badaa: 2008-04-18 * Support for Classical Mongolian Script (SCMS) joint with Jiayanmin
{
if ( bVertL2R )
- aFrm.Pos().X() += pPrv->Frm().Width();
+ maFrm.Pos().X() += pPrv->Frm().Width();
else
- aFrm.Pos().X() -= aFrm.Width();
+ maFrm.Pos().X() -= maFrm.Width();
}
}
else
- aFrm.Pos().Y() += pPrv->Frm().Height();
+ maFrm.Pos().Y() += pPrv->Frm().Height();
}
else if ( GetUpper() )
{
@@ -589,55 +589,55 @@ void SwFrm::MakePos()
pPrv = lcl_Prev( this, false );
if ( !bUseUpper && pPrv )
{
- aFrm.Pos( pPrv->Frm().Pos() );
+ maFrm.Pos( pPrv->Frm().Pos() );
if( FRM_NEIGHBOUR & nMyType )
{
sal_Bool bR2L = IsRightToLeft();
if( bR2L )
- (aFrm.*fnRect->fnSetPosX)( (aFrm.*fnRect->fnGetLeft)() -
- (aFrm.*fnRect->fnGetWidth)() );
+ (maFrm.*fnRect->fnSetPosX)( (maFrm.*fnRect->fnGetLeft)() -
+ (maFrm.*fnRect->fnGetWidth)() );
else
- (aFrm.*fnRect->fnSetPosX)( (aFrm.*fnRect->fnGetLeft)() +
+ (maFrm.*fnRect->fnSetPosX)( (maFrm.*fnRect->fnGetLeft)() +
(pPrv->Frm().*fnRect->fnGetWidth)() );
// cells may now leave their uppers
- if( bVert && FRM_CELL & nMyType && !bReverse )
- aFrm.Pos().X() -= aFrm.Width() -pPrv->Frm().Width();
+ if( bVert && FRM_CELL & nMyType && !mbReverse )
+ maFrm.Pos().X() -= maFrm.Width() -pPrv->Frm().Width();
}
else if( bVert && FRM_NOTE_VERT & nMyType )
{
- if( bReverse )
- aFrm.Pos().X() += pPrv->Frm().Width();
+ if( mbReverse )
+ maFrm.Pos().X() += pPrv->Frm().Width();
else
- aFrm.Pos().X() -= aFrm.Width();
+ maFrm.Pos().X() -= maFrm.Width();
}
else
- aFrm.Pos().Y() += pPrv->Frm().Height();
+ maFrm.Pos().Y() += pPrv->Frm().Height();
}
else
{
- aFrm.Pos( GetUpper()->Frm().Pos() );
- aFrm.Pos() += GetUpper()->Prt().Pos();
+ maFrm.Pos( GetUpper()->Frm().Pos() );
+ maFrm.Pos() += GetUpper()->Prt().Pos();
if( FRM_NEIGHBOUR & nMyType && IsRightToLeft() )
{
if( bVert )
- aFrm.Pos().Y() += GetUpper()->Prt().Height()
- - aFrm.Height();
+ maFrm.Pos().Y() += GetUpper()->Prt().Height()
+ - maFrm.Height();
else
- aFrm.Pos().X() += GetUpper()->Prt().Width()
- - aFrm.Width();
+ maFrm.Pos().X() += GetUpper()->Prt().Width()
+ - maFrm.Width();
}
//Badaa: 2008-04-18 * Support for Classical Mongolian Script (SCMS) joint with Jiayanmin
- else if( bVert && !bVertL2R && FRM_NOTE_VERT & nMyType && !bReverse )
- aFrm.Pos().X() -= aFrm.Width() - GetUpper()->Prt().Width();
+ else if( bVert && !bVertL2R && FRM_NOTE_VERT & nMyType && !mbReverse )
+ maFrm.Pos().X() -= maFrm.Width() - GetUpper()->Prt().Width();
}
}
else
- aFrm.Pos().X() = aFrm.Pos().Y() = 0;
+ maFrm.Pos().X() = maFrm.Pos().Y() = 0;
//Badaa: 2008-04-18 * Support for Classical Mongolian Script (SCMS) joint with Jiayanmin
- if( IsBodyFrm() && bVert && !bVertL2R && !bReverse && GetUpper() )
- aFrm.Pos().X() += GetUpper()->Prt().Width() - aFrm.Width();
- bValidPos = sal_True;
+ if( IsBodyFrm() && bVert && !bVertL2R && !mbReverse && GetUpper() )
+ maFrm.Pos().X() += GetUpper()->Prt().Width() - maFrm.Width();
+ mbValidPos = sal_True;
}
}
@@ -686,22 +686,22 @@ void SwPageFrm::MakeAll()
SwBorderAttrAccess *pAccess = 0;
const SwBorderAttrs*pAttrs = 0;
- while ( !bValidPos || !bValidSize || !bValidPrtArea )
+ while ( !mbValidPos || !mbValidSize || !mbValidPrtArea )
{
- if ( !bValidPos )
+ if ( !mbValidPos )
{
// PAGES01
- bValidPos = sal_True; // positioning of the pages is taken care of by the root frame
+ mbValidPos = sal_True; // positioning of the pages is taken care of by the root frame
}
- if ( !bValidSize || !bValidPrtArea )
+ if ( !mbValidSize || !mbValidPrtArea )
{
if ( IsEmptyPage() )
{
Frm().Width( 0 ); Prt().Width( 0 );
Frm().Height( 0 ); Prt().Height( 0 );
Prt().Left( 0 ); Prt().Top( 0 );
- bValidSize = bValidPrtArea = sal_True;
+ mbValidSize = mbValidPrtArea = sal_True;
}
else
{
@@ -801,7 +801,7 @@ void SwPageFrm::MakeAll()
Prt().Width( Frm().Width() - ( Prt().Left()
+ pAttrs->CalcRightLine() + aBorder.Width() ) );
Prt().Height( Frm().Height() - (nTop + nBottom) );
- bValidSize = bValidPrtArea = sal_True;
+ mbValidSize = mbValidPrtArea = sal_True;
}
else
{ // Set FixSize. For pages, this is not done from Upper, but from
@@ -811,14 +811,14 @@ void SwPageFrm::MakeAll()
}
}
}
- } //while ( !bValidPos || !bValidSize || !bValidPrtArea )
+ } //while ( !mbValidPos || !mbValidSize || !mbValidPrtArea )
delete pAccess;
// PAGES01
if ( Frm() != aOldRect && GetUpper() )
static_cast<SwRootFrm*>(GetUpper())->CheckViewLayout( 0, 0 );
- OSL_ENSURE( !GetUpper() || GetUpper()->Prt().Width() >= aFrm.Width(),
+ OSL_ENSURE( !GetUpper() || GetUpper()->Prt().Width() >= maFrm.Width(),
"Upper (Root) must be wide enough to contain the widest page");
}
@@ -842,9 +842,9 @@ void SwLayoutFrm::MakeAll()
SwBorderAttrAccess *pAccess = 0;
const SwBorderAttrs*pAttrs = 0;
- while ( !bValidPos || !bValidSize || !bValidPrtArea )
+ while ( !mbValidPos || !mbValidSize || !mbValidPrtArea )
{
- if ( !bValidPos )
+ if ( !mbValidPos )
MakePos();
if ( GetUpper() )
@@ -852,15 +852,15 @@ void SwLayoutFrm::MakeAll()
// NEW TABLES
if ( IsLeaveUpperAllowed() )
{
- if ( !bValidSize )
- bValidPrtArea = sal_False;
+ if ( !mbValidSize )
+ mbValidPrtArea = sal_False;
}
else
{
- if ( !bValidSize )
+ if ( !mbValidSize )
{
// Set FixSize; VarSize is set by Format() after calculating the PrtArea
- bValidPrtArea = sal_False;
+ mbValidPrtArea = sal_False;
SwTwips nPrtWidth = (GetUpper()->Prt().*fnRect->fnGetWidth)();
if( bVert && ( IsBodyFrm() || IsFtnContFrm() ) )
@@ -889,11 +889,11 @@ void SwLayoutFrm::MakeAll()
// Don't leave your upper
const SwTwips nDeadLine = (GetUpper()->*fnRect->fnGetPrtBottom)();
if( (Frm().*fnRect->fnOverStep)( nDeadLine ) )
- bValidSize = sal_False;
+ mbValidSize = sal_False;
}
}
}
- if ( !bValidSize || !bValidPrtArea )
+ if ( !mbValidSize || !mbValidPrtArea )
{
if ( !pAccess )
{
@@ -902,7 +902,7 @@ void SwLayoutFrm::MakeAll()
}
Format( pAttrs );
}
- } //while ( !bValidPos || !bValidSize || !bValidPrtArea )
+ } //while ( !mbValidPos || !mbValidSize || !mbValidPrtArea )
delete pAccess;
}
@@ -952,9 +952,9 @@ sal_Bool SwCntntFrm::MakePrtArea( const SwBorderAttrs &rAttrs )
{
sal_Bool bSizeChgd = sal_False;
- if ( !bValidPrtArea )
+ if ( !mbValidPrtArea )
{
- bValidPrtArea = sal_True;
+ mbValidPrtArea = sal_True;
SWRECTFN( this )
const bool bTxtFrm = IsTxtFrm();
@@ -1054,7 +1054,7 @@ sal_Bool SwCntntFrm::MakePrtArea( const SwBorderAttrs &rAttrs )
nLower=0;
}
- (Prt().*fnRect->fnSetPosY)( (!bVert || bReverse) ? nUpper : nLower);
+ (Prt().*fnRect->fnSetPosY)( (!bVert || mbReverse) ? nUpper : nLower);
nUpper += nLower;
nUpper -= (Frm().*fnRect->fnGetHeight)() -
(Prt().*fnRect->fnGetHeight)();
@@ -1087,8 +1087,8 @@ inline void ValidateSz( SwFrm *pFrm )
{
if ( pFrm )
{
- pFrm->bValidSize = sal_True;
- pFrm->bValidPrtArea = sal_True;
+ pFrm->mbValidSize = sal_True;
+ pFrm->mbValidPrtArea = sal_True;
}
}
@@ -1239,7 +1239,7 @@ void SwCntntFrm::MakeAll()
// OD 08.11.2002 #104840# - check footnote content for forward move.
// If a content of a footnote is on a prior page/column as its invalid
// reference, it can be moved forward.
- if ( bFtn && !bValidPos )
+ if ( bFtn && !mbValidPos )
{
SwFtnFrm* pFtn = FindFtnFrm();
SwCntntFrm* pRefCnt = pFtn ? pFtn->GetRef() : 0;
@@ -1260,7 +1260,7 @@ void SwCntntFrm::MakeAll()
SWRECTFN( this )
- while ( !bValidPos || !bValidSize || !bValidPrtArea )
+ while ( !mbValidPos || !mbValidSize || !mbValidPrtArea )
{
// - loop prevention
SwRect aOldFrm_StopFormat( Frm() );
@@ -1290,11 +1290,11 @@ void SwCntntFrm::MakeAll()
aOldFrmPos = (Frm().*fnRect->fnGetPos)();
aOldPrtPos = (Prt().*fnRect->fnGetPos)();
- if ( !bValidPos )
+ if ( !mbValidPos )
MakePos();
//Set FixSize. VarSize is being adjusted by Format().
- if ( !bValidSize )
+ if ( !mbValidSize )
{
// #125452#
// invalidate printing area flag, if the following conditions are hold:
@@ -1309,16 +1309,16 @@ void SwCntntFrm::MakeAll()
// triggered by method call <SwCrsrShell::SetCrsr()> after
// loading the document.
const SwTwips nNewFrmWidth = (GetUpper()->Prt().*fnRect->fnGetWidth)();
- if ( bValidPrtArea && nNewFrmWidth > 0 &&
+ if ( mbValidPrtArea && nNewFrmWidth > 0 &&
(Frm().*fnRect->fnGetWidth)() == 0 &&
(Prt().*fnRect->fnGetWidth)() == 0 )
{
- bValidPrtArea = sal_False;
+ mbValidPrtArea = sal_False;
}
(Frm().*fnRect->fnSetWidth)( nNewFrmWidth );
}
- if ( !bValidPrtArea )
+ if ( !mbValidPrtArea )
{
const long nOldW = (Prt().*fnRect->fnGetWidth)();
// #i34730# - keep current frame height
@@ -1332,7 +1332,7 @@ void SwCntntFrm::MakeAll()
// <SwTxtFrm::CalcPreps()>, if the already formatted lines still
// fit and if not, performs necessary actions.
// #i40150# - no check, if frame is undersized.
- if ( bValidSize && !IsUndersized() &&
+ if ( mbValidSize && !IsUndersized() &&
nOldH != (Frm().*fnRect->fnGetHeight)() )
{
// #115759# - no PREP_ADJUST_FRM and size
@@ -1347,7 +1347,7 @@ void SwCntntFrm::MakeAll()
if ( !bNoPrepAdjustFrm )
{
Prepare( PREP_ADJUST_FRM );
- bValidSize = sal_False;
+ mbValidSize = sal_False;
}
}
}
@@ -1364,23 +1364,23 @@ void SwCntntFrm::MakeAll()
( (Frm().*fnRect->fnOverStep)( nDeadLine ) ) ) )
{
Prepare( PREP_WIDOWS_ORPHANS, 0, sal_False );
- bValidSize = bWidow = sal_False;
+ mbValidSize = bWidow = sal_False;
}
if( (Frm().*fnRect->fnGetPos)() != aOldFrmPos ||
(Prt().*fnRect->fnGetPos)() != aOldPrtPos )
{
// In this Prepare, an _InvalidateSize() might happen.
- // bValidSize becomes sal_False and Format() gets called.
+ // mbValidSize becomes sal_False and Format() gets called.
Prepare( PREP_POS_CHGD, (const void*)&bFormatted, sal_False );
if ( bWidow && GetFollow() )
{ Prepare( PREP_WIDOWS_ORPHANS, 0, sal_False );
- bValidSize = sal_False;
+ mbValidSize = sal_False;
}
}
}
- if ( !bValidSize )
+ if ( !mbValidSize )
{
- bValidSize = bFormatted = sal_True;
+ mbValidSize = bFormatted = sal_True;
++nFormatCount;
if( nFormatCount > STOP_FLY_FORMAT )
SetFlyLock( sal_True );
@@ -1426,11 +1426,11 @@ void SwCntntFrm::MakeAll()
if( aOldPos != (Frm().*fnRect->fnGetPos)() )
{
Prepare( PREP_POS_CHGD, (const void*)&bFormatted, sal_False );
- if ( !bValidSize )
+ if ( !mbValidSize )
{
(Frm().*fnRect->fnSetWidth)( (GetUpper()->
Prt().*fnRect->fnGetWidth)() );
- if ( !bValidPrtArea )
+ if ( !mbValidPrtArea )
{
const long nOldW = (Prt().*fnRect->fnGetWidth)();
MakePrtArea( rAttrs );
@@ -1439,7 +1439,7 @@ void SwCntntFrm::MakeAll()
}
if( GetFollow() )
Prepare( PREP_WIDOWS_ORPHANS, 0, sal_False );
- bValidSize = bFormatted = sal_True;
+ mbValidSize = bFormatted = sal_True;
Format();
}
}
@@ -1460,17 +1460,17 @@ void SwCntntFrm::MakeAll()
if ( pNxt )
{
pNxt->Calc();
- if( bValidPos && !GetIndNext() )
+ if( mbValidPos && !GetIndNext() )
{
SwSectionFrm *pSct = FindSctFrm();
if( pSct && !pSct->GetValidSizeFlag() )
{
SwSectionFrm* pNxtSct = pNxt->FindSctFrm();
if( pNxtSct && pSct->IsAnFollow( pNxtSct ) )
- bValidPos = sal_False;
+ mbValidPos = sal_False;
}
else
- bValidPos = sal_False;
+ mbValidPos = sal_False;
}
}
}
@@ -1478,7 +1478,7 @@ void SwCntntFrm::MakeAll()
// In footnotes, the TxtFrm may validate itself, which can lead to the
// situation that it's position is wrong despite being "valid".
- if ( bValidPos )
+ if ( mbValidPos )
{
// #i59341#
// Workaround for inadequate layout algorithm:
@@ -1491,7 +1491,7 @@ void SwCntntFrm::MakeAll()
nFormatCount <= STOP_FLY_FORMAT &&
!GetDrawObjs() )
{
- bValidPos = sal_False;
+ mbValidPos = sal_False;
MakePos();
aOldFrmPos = (Frm().*fnRect->fnGetPos)();
aOldPrtPos = (Prt().*fnRect->fnGetPos)();
@@ -1512,7 +1512,7 @@ void SwCntntFrm::MakeAll()
}
// Yet again an invalid value? Repeat from the start...
- if ( !bValidPos || !bValidSize || !bValidPrtArea )
+ if ( !mbValidPos || !mbValidSize || !mbValidPrtArea )
continue;
// Done?
@@ -1621,7 +1621,7 @@ void SwCntntFrm::MakeAll()
if ( nTmp > 0 && WouldFit( nTmp, bSplit, sal_False ) )
{
Prepare( PREP_WIDOWS_ORPHANS, 0, sal_False );
- bValidSize = sal_False;
+ mbValidSize = sal_False;
bFitPromise = true;
continue;
}
@@ -1695,7 +1695,7 @@ void SwCntntFrm::MakeAll()
if ( nConsequetiveFormatsWithoutChange <= cnStopFormat )
{
Prepare( PREP_MUST_FIT, 0, sal_False );
- bValidSize = sal_False;
+ mbValidSize = sal_False;
bMustFit = true;
continue;
}
@@ -1711,7 +1711,7 @@ void SwCntntFrm::MakeAll()
::ValidateSz( pPre );
}
- } //while ( !bValidPos || !bValidSize || !bValidPrtArea )
+ } //while ( !mbValidPos || !mbValidSize || !mbValidPrtArea )
// NEW: Looping Louie (Light). Should not be applied in balanced sections.
@@ -1762,7 +1762,7 @@ void MakeNxt( SwFrm *pFrm, SwFrm *pNxt )
const sal_Bool bOldPos = pFrm->GetValidPosFlag();
const sal_Bool bOldSz = pFrm->GetValidSizeFlag();
const sal_Bool bOldPrt = pFrm->GetValidPrtAreaFlag();
- pFrm->bValidPos = pFrm->bValidPrtArea = pFrm->bValidSize = sal_True;
+ pFrm->mbValidPos = pFrm->mbValidPrtArea = pFrm->mbValidSize = sal_True;
// fix(29272): Don't call MakeAll - there, pFrm might be invalidated again, and
// we recursively end up in here again.
@@ -1796,9 +1796,9 @@ void MakeNxt( SwFrm *pFrm, SwFrm *pNxt )
pNxt->Format( &rAttrs );
}
- pFrm->bValidPos = bOldPos;
- pFrm->bValidSize = bOldSz;
- pFrm->bValidPrtArea = bOldPrt;
+ pFrm->mbValidPos = bOldPos;
+ pFrm->mbValidSize = bOldSz;
+ pFrm->mbValidPrtArea = bOldPrt;
}
// This routine checks whether there are no other FtnBosses
diff --git a/sw/source/core/layout/colfrm.cxx b/sw/source/core/layout/colfrm.cxx
index f8522c1..2e0f222 100644
--- a/sw/source/core/layout/colfrm.cxx
+++ b/sw/source/core/layout/colfrm.cxx
@@ -49,7 +49,7 @@ void sw_RemoveFtns( SwFtnBossFrm* pBoss, sal_Bool bPageOnly, sal_Bool bEndNotes
SwColumnFrm::SwColumnFrm( SwFrmFmt *pFmt, SwFrm* pSib ):
SwFtnBossFrm( pFmt, pSib )
{
- nType = FRMC_COLUMN;
+ mnType = FRMC_COLUMN;
SwBodyFrm* pColBody = new SwBodyFrm( pFmt->GetDoc()->GetDfltFrmFmt(), pSib );
pColBody->InsertBehind( this, 0 ); // ColumnFrms now with BodyFrm
SetMaxFtnHeight( LONG_MAX );
diff --git a/sw/source/core/layout/flowfrm.cxx b/sw/source/core/layout/flowfrm.cxx
index 188a760..7cbd750 100644
--- a/sw/source/core/layout/flowfrm.cxx
+++ b/sw/source/core/layout/flowfrm.cxx
@@ -440,8 +440,8 @@ SwLayoutFrm *SwFlowFrm::CutTree( SwFrm *pStart )
pStart->GetUpper()->pLower = 0;
if ( pStart->GetPrev() )
{
- pStart->GetPrev()->pNext = 0;
- pStart->pPrev = 0;
+ pStart->GetPrev()->mpNext = 0;
+ pStart->mpPrev = 0;
}
if ( pLay->IsFtnFrm() )
@@ -495,8 +495,8 @@ sal_Bool SwFlowFrm::PasteTree( SwFrm *pStart, SwLayoutFrm *pParent, SwFrm *pSibl
// On the way there, we invalidate as required.
if ( pSibling )
{
- if ( 0 != (pStart->pPrev = pSibling->GetPrev()) )
- pStart->GetPrev()->pNext = pStart;
+ if ( 0 != (pStart->mpPrev = pSibling->GetPrev()) )
+ pStart->GetPrev()->mpNext = pStart;
else
pParent->pLower = pStart;
pSibling->_InvalidatePos();
@@ -504,7 +504,7 @@ sal_Bool SwFlowFrm::PasteTree( SwFrm *pStart, SwLayoutFrm *pParent, SwFrm *pSibl
}
else
{
- if ( 0 == (pStart->pPrev = pParent->Lower()) )
+ if ( 0 == (pStart->mpPrev = pParent->Lower()) )
pParent->pLower = pStart;
else
//Modified for #i100782#,04/03/2009
@@ -518,12 +518,12 @@ sal_Bool SwFlowFrm::PasteTree( SwFrm *pStart, SwLayoutFrm *pParent, SwFrm *pSibl
SwFrm* pTemp = pParent->pLower;
while (pTemp)
{
- if (pTemp->pNext)
- pTemp = pTemp->pNext;
+ if (pTemp->mpNext)
+ pTemp = pTemp->mpNext;
else
{
- pStart->pPrev = pTemp;
- pTemp->pNext = pStart;
+ pStart->mpPrev = pTemp;
+ pTemp->mpNext = pStart;
break;
}
}
@@ -546,7 +546,7 @@ sal_Bool SwFlowFrm::PasteTree( SwFrm *pStart, SwLayoutFrm *pParent, SwFrm *pSibl
SWRECTFN( pParent )
SwTwips nGrowVal = 0;
do
- { pFloat->pUpper = pParent;
+ { pFloat->mpUpper = pParent;
pFloat->_InvalidateAll();
pFloat->CheckDirChange();
@@ -572,8 +572,8 @@ sal_Bool SwFlowFrm::PasteTree( SwFrm *pStart, SwLayoutFrm *pParent, SwFrm *pSibl
if ( pSibling )
{
- pLst->pNext = pSibling;
- pSibling->pPrev = pLst;
+ pLst->mpNext = pSibling;
+ pSibling->mpPrev = pLst;
if( pSibling->IsInFtn() )
{
if( pSibling->IsSctFrm() )
@@ -2471,7 +2471,7 @@ sal_Bool SwFlowFrm::MoveBwd( sal_Bool &rbReformat )
{
pSectFrm->DelEmpty( sal_True );
delete pSectFrm;
- rThis.bValidPos = sal_True;
+ rThis.mbValidPos = sal_True;
}
}
}
diff --git a/sw/source/core/layout/fly.cxx b/sw/source/core/layout/fly.cxx
index 8a86071..77c4692 100644
--- a/sw/source/core/layout/fly.cxx
+++ b/sw/source/core/layout/fly.cxx
@@ -102,7 +102,7 @@ SwFlyFrm::SwFlyFrm( SwFlyFrmFmt *pFmt, SwFrm* pSib, SwFrm *pAnch ) :
bNoShrink( sal_False ),
bLockDeleteContent( sal_False )
{
- nType = FRMC_FLY;
+ mnType = FRMC_FLY;
bInvalid = bNotifyBack = sal_True;
bLocked = bMinHeight =
@@ -114,19 +114,19 @@ SwFlyFrm::SwFlyFrm( SwFlyFrmFmt *pFmt, SwFrm* pSib, SwFrm *pAnch ) :
((SvxFrameDirectionItem&)pFmt->GetFmtAttr( RES_FRAMEDIR )).GetValue();
if( FRMDIR_ENVIRONMENT == nDir )
{
- bDerivedVert = 1;
- bDerivedR2L = 1;
+ mbDerivedVert = 1;
+ mbDerivedR2L = 1;
}
else
{
- bInvalidVert = 0;
- bDerivedVert = 0;
- bDerivedR2L = 0;
+ mbInvalidVert = 0;
+ mbDerivedVert = 0;
+ mbDerivedR2L = 0;
if( FRMDIR_HORI_LEFT_TOP == nDir || FRMDIR_HORI_RIGHT_TOP == nDir )
{
//Badaa: 2008-04-18 * Support for Classical Mongolian Script (SCMS) joint with Jiayanmin
- bVertLR = 0;
- bVertical = 0;
+ mbVertLR = 0;
+ mbVertical = 0;
}
else
{
@@ -134,25 +134,25 @@ SwFlyFrm::SwFlyFrm( SwFlyFrmFmt *pFmt, SwFrm* pSib, SwFrm *pAnch ) :
if( pSh && pSh->GetViewOptions()->getBrowseMode() )
{
//Badaa: 2008-04-18 * Support for Classical Mongolian Script (SCMS) joint with Jiayanmin
- bVertLR = 0;
- bVertical = 0;
+ mbVertLR = 0;
+ mbVertical = 0;
}
else
{
- bVertical = 1;
+ mbVertical = 1;
//Badaa: 2008-04-18 * Support for Classical Mongolian Script (SCMS) joint with Jiayanmin
if ( FRMDIR_VERT_TOP_LEFT == nDir )
- bVertLR = 1;
+ mbVertLR = 1;
else
- bVertLR = 0;
+ mbVertLR = 0;
}
}
- bInvalidR2L = 0;
+ mbInvalidR2L = 0;
if( FRMDIR_HORI_RIGHT_TOP == nDir )
- bRightToLeft = 1;
+ mbRightToLeft = 1;
else
- bRightToLeft = 0;
+ mbRightToLeft = 0;
}
Frm().Width( rFrmSize.GetWidth() );
@@ -162,7 +162,7 @@ SwFlyFrm::SwFlyFrm( SwFlyFrmFmt *pFmt, SwFrm* pSib, SwFrm *pAnch ) :
if ( rFrmSize.GetHeightSizeType() == ATT_MIN_SIZE )
bMinHeight = sal_True;
else if ( rFrmSize.GetHeightSizeType() == ATT_FIX_SIZE )
- bFixSize = sal_True;
+ mbFixSize = sal_True;
// insert columns, if necessary
InsertColumns();
@@ -225,7 +225,7 @@ void SwFlyFrm::InsertCnt()
// NoTxt always have a fixed height.
if ( Lower() && Lower()->IsNoTxtFrm() )
{
- bFixSize = sal_True;
+ mbFixSize = sal_True;
bMinHeight = sal_False;
}
}
@@ -705,17 +705,17 @@ sal_Bool SwFlyFrm::FrmSizeChg( const SwFmtFrmSize &rFrmSize )
sal_Bool bRet = sal_False;
SwTwips nDiffHeight = Frm().Height();
if ( rFrmSize.GetHeightSizeType() == ATT_VAR_SIZE )
- bFixSize = bMinHeight = sal_False;
+ mbFixSize = bMinHeight = sal_False;
else
{
if ( rFrmSize.GetHeightSizeType() == ATT_FIX_SIZE )
{
- bFixSize = sal_True;
+ mbFixSize = sal_True;
bMinHeight = sal_False;
}
else if ( rFrmSize.GetHeightSizeType() == ATT_MIN_SIZE )
{
- bFixSize = sal_False;
+ mbFixSize = sal_False;
bMinHeight = sal_True;
}
nDiffHeight -= rFrmSize.GetHeight();
@@ -730,20 +730,20 @@ sal_Bool SwFlyFrm::FrmSizeChg( const SwFmtFrmSize &rFrmSize )
const SwRect aOld( GetObjRectWithSpaces() );
const Size aOldSz( Prt().SSize() );
const SwTwips nDiffWidth = Frm().Width() - rFrmSize.GetWidth();
- aFrm.Height( aFrm.Height() - nDiffHeight );
- aFrm.Width ( aFrm.Width() - nDiffWidth );
+ maFrm.Height( maFrm.Height() - nDiffHeight );
+ maFrm.Width ( maFrm.Width() - nDiffWidth );
// #i68520#
InvalidateObjRectWithSpaces();
- aPrt.Height( aPrt.Height() - nDiffHeight );
- aPrt.Width ( aPrt.Width() - nDiffWidth );
+ maPrt.Height( maPrt.Height() - nDiffHeight );
+ maPrt.Width ( maPrt.Width() - nDiffWidth );
ChgLowersProp( aOldSz );
::Notify( this, FindPageFrm(), aOld );
- bValidPos = sal_False;
+ mbValidPos = sal_False;
bRet = sal_True;
}
else if ( Lower()->IsNoTxtFrm() )
{
- bFixSize = sal_True;
+ mbFixSize = sal_True;
bMinHeight = sal_False;
}
}
@@ -907,7 +907,7 @@ void SwFlyFrm::_UpdateAttr( const SfxPoolItem *pOld, const SfxPoolItem *pNew,
if ( RES_FMT_CHG == nWhich )
{
SwRect aNew( GetObjRectWithSpaces() );
- SwRect aOld( aFrm );
+ SwRect aOld( maFrm );
const SvxULSpaceItem &rUL = ((SwFmtChg*)pOld)->pChangedFmt->GetULSpace();
aOld.Top( Max( aOld.Top() - long(rUL.GetUpper()), 0L ) );
aOld.SSize().Height()+= rUL.GetLower();
@@ -997,7 +997,7 @@ void SwFlyFrm::_UpdateAttr( const SfxPoolItem *pOld, const SfxPoolItem *pNew,
if( pSh && pSh->GetViewOptions()->getBrowseMode() )
getRootFrm()->InvalidateBrowseWidth();
SwRect aNew( GetObjRectWithSpaces() );
- SwRect aOld( aFrm );
+ SwRect aOld( maFrm );
if ( RES_UL_SPACE == nWhich )
{
const SvxULSpaceItem &rUL = *(SvxULSpaceItem*)pNew;
@@ -1319,7 +1319,7 @@ void SwFlyFrm::Format( const SwBorderAttrs *pAttrs )
ColLock();
- if ( !bValidSize )
+ if ( !mbValidSize )
{
if ( Frm().Top() == FAR_AWAY && Frm().Left() == FAR_AWAY )
{
@@ -1333,7 +1333,7 @@ void SwFlyFrm::Format( const SwBorderAttrs *pAttrs )
if ( Lower() && Lower()->IsColumnFrm() )
AdjustColumns( 0, sal_False );
- bValidSize = sal_True;
+ mbValidSize = sal_True;
const SwTwips nUL = pAttrs->CalcTopLine() + pAttrs->CalcBottomLine();
const SwTwips nLR = pAttrs->CalcLeftLine() + pAttrs->CalcRightLine();
@@ -1427,11 +1427,11 @@ void SwFlyFrm::Format( const SwBorderAttrs *pAttrs )
{
InvalidateObjRectWithSpaces();
}
- bValidSize = sal_True;
+ mbValidSize = sal_True;
}
else
{
- bValidSize = sal_True; //Fixe Frms formatieren sich nicht.
+ mbValidSize = sal_True; //Fixe Frms formatieren sich nicht.
//Flys stellen ihre Groesse anhand des Attr ein.
SwTwips nNewSize = bVert ? aRelSize.Width() : aRelSize.Height();
nNewSize -= nUL;
@@ -1810,9 +1810,9 @@ void CalcCntnt( SwLayoutFrm *pLay,
//void SwFlyFrm::MakeFlyPos()
void SwFlyFrm::MakeObjPos()
{
- if ( !bValidPos )
+ if ( !mbValidPos )
{
- bValidPos = sal_True;
+ mbValidPos = sal_True;
// OD 29.10.2003 #113049# - use new class to position object
GetAnchorFrm()->Calc();
@@ -1825,8 +1825,8 @@ void SwFlyFrm::MakeObjPos()
SetCurrRelPos( aObjPositioning.GetRelPos() );
SWRECTFN( GetAnchorFrm() );
- aFrm.Pos( aObjPositioning.GetRelPos() );
- aFrm.Pos() += (GetAnchorFrm()->Frm().*fnRect->fnGetPos)();
+ maFrm.Pos( aObjPositioning.GetRelPos() );
+ maFrm.Pos() += (GetAnchorFrm()->Frm().*fnRect->fnGetPos)();
// #i69335#
InvalidateObjRectWithSpaces();
}
@@ -1840,9 +1840,9 @@ void SwFlyFrm::MakeObjPos()
void SwFlyFrm::MakePrtArea( const SwBorderAttrs &rAttrs )
{
- if ( !bValidPrtArea )
+ if ( !mbValidPrtArea )
{
- bValidPrtArea = sal_True;
+ mbValidPrtArea = sal_True;
// OD 31.07.2003 #110978# - consider vertical layout
SWRECTFN( this )
@@ -1898,7 +1898,7 @@ SwTwips SwFlyFrm::_Grow( SwTwips nDist, sal_Bool bTst )
// Writer fly frames - inner Writer fly frames format its
// anchor, which grows/shrinks the outer Writer fly frame.
// Note: position will be invalidated below.
- bValidPos = sal_True;
+ mbValidPos = sal_True;
// #i55416#
// Suppress format of width for autowidth frame, because the
// format of the width would call <SwTxtFrm::CalcFitToContent()>
@@ -1993,7 +1993,7 @@ SwTwips SwFlyFrm::_Shrink( SwTwips nDist, sal_Bool bTst )
// Writer fly frames - inner Writer fly frames format its
// anchor, which grows/shrinks the outer Writer fly frame.
// Note: position will be invalidated below.
- bValidPos = sal_True;
+ mbValidPos = sal_True;
// #i55416#
// Suppress format of width for autowidth frame, because the
// format of the width would call <SwTxtFrm::CalcFitToContent()>
@@ -2121,9 +2121,9 @@ void SwFlyFrm::Cut()
void SwFrm::AppendFly( SwFlyFrm *pNew )
{
- if ( !pDrawObjs )
- pDrawObjs = new SwSortedObjs();
- pDrawObjs->Insert( *pNew );
+ if ( !mpDrawObjs )
+ mpDrawObjs = new SwSortedObjs();
+ mpDrawObjs->Insert( *pNew );
pNew->ChgAnchorFrm( this );
//Bei der Seite anmelden; kann sein, dass noch keine da ist - die
@@ -2191,9 +2191,9 @@ void SwFrm::RemoveFly( SwFlyFrm *pToRemove )
}
}
- pDrawObjs->Remove( *pToRemove );
- if ( !pDrawObjs->Count() )
- DELETEZ( pDrawObjs );
+ mpDrawObjs->Remove( *pToRemove );
+ if ( !mpDrawObjs->Count() )
+ DELETEZ( mpDrawObjs );
pToRemove->ChgAnchorFrm( 0 );
@@ -2227,9 +2227,9 @@ void SwFrm::AppendDrawObj( SwAnchoredObject& _rNewObj )
if ( _rNewObj.GetAnchorFrm() != this )
{
- if ( !pDrawObjs )
- pDrawObjs = new SwSortedObjs();
- pDrawObjs->Insert( _rNewObj );
+ if ( !mpDrawObjs )
+ mpDrawObjs = new SwSortedObjs();
+ mpDrawObjs->Insert( _rNewObj );
_rNewObj.ChgAnchorFrm( this );
}
@@ -2292,9 +2292,9 @@ void SwFrm::RemoveDrawObj( SwAnchoredObject& _rToRemoveObj )
if ( pPage && pPage->GetSortedObjs() )
pPage->RemoveDrawObjFromPage( _rToRemoveObj );
- pDrawObjs->Remove( _rToRemoveObj );
- if ( !pDrawObjs->Count() )
- DELETEZ( pDrawObjs );
+ mpDrawObjs->Remove( _rToRemoveObj );
+ if ( !mpDrawObjs->Count() )
+ DELETEZ( mpDrawObjs );
_rToRemoveObj.ChgAnchorFrm( 0 );
}
diff --git a/sw/source/core/layout/flycnt.cxx b/sw/source/core/layout/flycnt.cxx
index 49544eb..d1bcb83 100644
--- a/sw/source/core/layout/flycnt.cxx
+++ b/sw/source/core/layout/flycnt.cxx
@@ -1468,13 +1468,13 @@ void SwFlyAtCntFrm::RegisterAtCorrectPage()
void SwFlyAtCntFrm::MakeObjPos()
{
// if fly frame position is valid, nothing is to do. Thus, return
- if ( bValidPos )
+ if ( mbValidPos )
{
return;
}
// #i26791# - validate position flag here.
- bValidPos = sal_True;
+ mbValidPos = sal_True;
// #i35911# - no calculation of new position, if
// anchored object is marked that it clears its environment and its
diff --git a/sw/source/core/layout/flyincnt.cxx b/sw/source/core/layout/flyincnt.cxx
index 4936759..671c249 100644
--- a/sw/source/core/layout/flyincnt.cxx
+++ b/sw/source/core/layout/flyincnt.cxx
@@ -90,7 +90,7 @@ void SwFlyInCntFrm::SetRefPoint( const Point& rPoint,
if( pNotify )
{
InvalidatePage();
- bValidPos = sal_False;
+ mbValidPos = sal_False;
bInvalid = sal_True;
Calc();
delete pNotify;
@@ -173,9 +173,9 @@ void SwFlyInCntFrm::Format( const SwBorderAttrs *pAttrs )
//void SwFlyInCntFrm::MakeFlyPos()
void SwFlyInCntFrm::MakeObjPos()
{
- if ( !bValidPos )
+ if ( !mbValidPos )
{
- bValidPos = sal_True;
+ mbValidPos = sal_True;
SwFlyFrmFmt *pFmt = (SwFlyFrmFmt*)GetFmt();
const SwFmtVertOrient &rVert = pFmt->GetVertOrient();
//Update the current values in the format if needed, during this we of
@@ -265,23 +265,23 @@ void SwFlyInCntFrm::MakeAll()
const SwBorderAttrs &rAttrs = *aAccess.Get();
if ( IsClipped() )
- bValidSize = bHeightClipped = bWidthClipped = sal_False;
+ mbValidSize = bHeightClipped = bWidthClipped = sal_False;
- while ( !bValidPos || !bValidSize || !bValidPrtArea )
+ while ( !mbValidPos || !mbValidSize || !mbValidPrtArea )
{
//Only stop, if the flag is set!!
- if ( !bValidSize )
+ if ( !mbValidSize )
{
- bValidPrtArea = sal_False;
+ mbValidPrtArea = sal_False;
}
- if ( !bValidPrtArea )
+ if ( !mbValidPrtArea )
MakePrtArea( rAttrs );
- if ( !bValidSize )
+ if ( !mbValidSize )
Format( &rAttrs );
- if ( !bValidPos )
+ if ( !mbValidPos )
{
// OD 2004-03-23 #i26791#
//MakeFlyPos();
@@ -291,7 +291,7 @@ void SwFlyInCntFrm::MakeAll()
//
// re-activate clipping of as-character anchored Writer fly frames
// depending on compatibility option <ClipAsCharacterAnchoredWriterFlyFrames>
- if ( bValidPos && bValidSize &&
+ if ( mbValidPos && mbValidSize &&
GetFmt()->getIDocumentSettingAccess()->get( IDocumentSettingAccess::CLIP_AS_CHARACTER_ANCHORED_WRITER_FLY_FRAME ) )
{
SwFrm* pFrm = AnchorFrm();
@@ -299,7 +299,7 @@ void SwFlyInCntFrm::MakeAll()
Frm().Width() > pFrm->Prt().Width() )
{
Frm().Width( pFrm->Prt().Width() );
- bValidPrtArea = sal_False;
+ mbValidPrtArea = sal_False;
bWidthClipped = sal_True;
}
}
diff --git a/sw/source/core/layout/flylay.cxx b/sw/source/core/layout/flylay.cxx
index 6f7a283..5da5036 100644
--- a/sw/source/core/layout/flylay.cxx
+++ b/sw/source/core/layout/flylay.cxx
@@ -149,7 +149,7 @@ void SwFlyFreeFrm::MakeAll()
if ( IsClipped() )
{
- bValidSize = bHeightClipped = bWidthClipped = sal_False;
+ mbValidSize = bHeightClipped = bWidthClipped = sal_False;
// no invalidation of position,
// if anchored object is anchored inside a Writer fly frame,
// its position is already locked, and it follows the text flow.
@@ -160,7 +160,7 @@ void SwFlyFreeFrm::MakeAll()
GetAnchorFrm()->IsInFly() &&
GetFrmFmt().GetFollowTextFlow().GetValue() ) )
{
- bValidPos = sal_False;
+ mbValidPos = sal_False;
}
}
@@ -168,7 +168,7 @@ void SwFlyFreeFrm::MakeAll()
sal_uInt16 nLoopControlRuns = 0;
const sal_uInt16 nLoopControlMax = 10;
- while ( !bValidPos || !bValidSize || !bValidPrtArea || bFormatHeightOnly )
+ while ( !mbValidPos || !mbValidSize || !mbValidPrtArea || bFormatHeightOnly )
{
SWRECTFN( this )
const SwFmtFrmSize *pSz;
@@ -179,43 +179,43 @@ void SwFlyFreeFrm::MakeAll()
pSz = &rAttrs.GetAttrSet().GetFrmSize();
// Only set when the flag is set!
- if ( !bValidSize )
+ if ( !mbValidSize )
{
- bValidPrtArea = sal_False;
+ mbValidPrtArea = sal_False;
}
- if ( !bValidPrtArea )
+ if ( !mbValidPrtArea )
MakePrtArea( rAttrs );
- if ( !bValidSize || bFormatHeightOnly )
+ if ( !mbValidSize || bFormatHeightOnly )
{
- bValidSize = sal_False;
+ mbValidSize = sal_False;
Format( &rAttrs );
bFormatHeightOnly = sal_False;
}
- if ( !bValidPos )
+ if ( !mbValidPos )
{
const Point aOldPos( (Frm().*fnRect->fnGetPos)() );
// #i26791# - use new method <MakeObjPos()>
// #i34753# - no positioning, if requested.
if ( IsNoMakePos() )
- bValidPos = sal_True;
+ mbValidPos = sal_True;
else
// #i26791# - use new method <MakeObjPos()>
MakeObjPos();
if( aOldPos == (Frm().*fnRect->fnGetPos)() )
{
- if( !bValidPos && GetAnchorFrm()->IsInSct() &&
+ if( !mbValidPos && GetAnchorFrm()->IsInSct() &&
!GetAnchorFrm()->FindSctFrm()->IsValid() )
- bValidPos = sal_True;
+ mbValidPos = sal_True;
}
else
- bValidSize = sal_False;
+ mbValidSize = sal_False;
}
}
- if ( bValidPos && bValidSize )
+ if ( mbValidPos && mbValidSize )
{
++nLoopControlRuns;
@@ -340,7 +340,7 @@ void SwFlyFreeFrm::CheckClip( const SwFmtFrmSize &rSz )
bWidthClipped = sal_True;
}
if ( bAgain )
- bValidSize = sal_False;
+ mbValidSize = sal_False;
else
{
// If we reach this branch, the Frm protrudes into forbidden
@@ -458,8 +458,8 @@ void SwFlyFreeFrm::CheckClip( const SwFmtFrmSize &rSz )
} while ( pLow );
::CalcCntnt( this );
ColUnlock();
- if ( !bValidSize && !bWidthClipped )
- bFormatHeightOnly = bValidSize = sal_True;
+ if ( !mbValidSize && !bWidthClipped )
+ bFormatHeightOnly = mbValidSize = sal_True;
}
else
{
diff --git a/sw/source/core/layout/frmtool.cxx b/sw/source/core/layout/frmtool.cxx
index f0bafde..8b43fe6 100644
--- a/sw/source/core/layout/frmtool.cxx
+++ b/sw/source/core/layout/frmtool.cxx
@@ -2506,13 +2506,13 @@ SwFrm *SaveCntnt( SwLayoutFrm *pLay, SwFrm *pStart )
if ( pFloat->GetNext() )
{
if( bGo )
- pFloat->pUpper = NULL;
+ pFloat->mpUpper = NULL;
pFloat = pFloat->GetNext();
if( !bGo && pFloat == pStart )
{
bGo = true;
- pFloat->pPrev->pNext = NULL;
- pFloat->pPrev = NULL;
+ pFloat->mpPrev->mpNext = NULL;
+ pFloat->mpPrev = NULL;
}
}
else
@@ -2523,7 +2523,7 @@ SwFrm *SaveCntnt( SwLayoutFrm *pLay, SwFrm *pStart )
//Die naechste Teilkette suchen und die Ketten miteinander verbinden.
SwFrm *pTmp = pFloat->FindNext();
if( bGo )
- pFloat->pUpper = NULL;
+ pFloat->mpUpper = NULL;
if( !pLay->IsInFtn() )
while( pTmp && pTmp->IsInFtn() )
@@ -2534,8 +2534,8 @@ SwFrm *SaveCntnt( SwLayoutFrm *pLay, SwFrm *pStart )
if ( pTmp && bGo )
{
- pFloat->pNext = pTmp; //Die beiden Ketten verbinden.
- pFloat->pNext->pPrev = pFloat;
+ pFloat->mpNext = pTmp; //Die beiden Ketten verbinden.
+ pFloat->mpNext->mpPrev = pFloat;
}
pFloat = pTmp;
bGo = bGo || ( pStart == pFloat );
@@ -2614,12 +2614,12 @@ void RestoreCntnt( SwFrm *pSav, SwLayoutFrm *pParent, SwFrm *pSibling, bool bGro
pPage->InvalidatePage( pPage ); //Invalides Layout anmelden.
//Vorgaenger festellen und die Verbindung herstellen bzw. initialisieren.
- pSav->pPrev = pSibling;
+ pSav->mpPrev = pSibling;
SwFrm* pNxt;
if ( pSibling )
{
- pNxt = pSibling->pNext;
- pSibling->pNext = pSav;
+ pNxt = pSibling->mpNext;
+ pSibling->mpNext = pSav;
pSibling->_InvalidatePrt();
((SwCntntFrm*)pSibling)->InvalidatePage( pPage );//Invaliden Cntnt anmelden.
if ( ((SwCntntFrm*)pSibling)->GetFollow() )
@@ -2628,7 +2628,7 @@ void RestoreCntnt( SwFrm *pSav, SwLayoutFrm *pParent, SwFrm *pSibling, bool bGro
else
{ pNxt = pParent->pLower;
pParent->pLower = pSav;
- pSav->pUpper = pParent; //Schon mal setzen, sonst ist fuer das
+ pSav->mpUpper = pParent; //Schon mal setzen, sonst ist fuer das
//invalidate der Parent (z.B. ein Fly) nicht klar.
//Invaliden Cntnt anmelden.
if ( pSav->IsCntntFrm() )
@@ -2645,7 +2645,7 @@ void RestoreCntnt( SwFrm *pSav, SwLayoutFrm *pParent, SwFrm *pSibling, bool bGro
SwTwips nGrowVal = 0;
SwFrm* pLast;
do
- { pSav->pUpper = pParent;
+ { pSav->mpUpper = pParent;
nGrowVal += (pSav->Frm().*fnRect->fnGetHeight)();
pSav->_InvalidateAll();
@@ -2680,8 +2680,8 @@ void RestoreCntnt( SwFrm *pSav, SwLayoutFrm *pParent, SwFrm *pSibling, bool bGro
if( pNxt )
{
- pLast->pNext = pNxt;
- pNxt->pPrev = pLast;
+ pLast->mpNext = pNxt;
+ pNxt->mpPrev = pLast;
}
if ( bGrow )
diff --git a/sw/source/core/layout/ftnfrm.cxx b/sw/source/core/layout/ftnfrm.cxx
index 47227b5..673f310 100644
--- a/sw/source/core/layout/ftnfrm.cxx
+++ b/sw/source/core/layout/ftnfrm.cxx
@@ -173,7 +173,7 @@ static sal_uInt16 lcl_ColumnNum( const SwFrm* pBoss )
SwFtnContFrm::SwFtnContFrm( SwFrmFmt *pFmt, SwFrm* pSib ):
SwLayoutFrm( pFmt, pSib )
{
- nType = FRMC_FTNCONT;
+ mnType = FRMC_FTNCONT;
}
@@ -225,17 +225,17 @@ void SwFtnContFrm::Format( const SwBorderAttrs * )
const SwTwips nBorder = rInf.GetTopDist() + rInf.GetBottomDist() +
rInf.GetLineWidth();
SWRECTFN( this )
- if ( !bValidPrtArea )
+ if ( !mbValidPrtArea )
{
- bValidPrtArea = sal_True;
+ mbValidPrtArea = sal_True;
(Prt().*fnRect->fnSetTop)( nBorder );
(Prt().*fnRect->fnSetWidth)( (Frm().*fnRect->fnGetWidth)() );
(Prt().*fnRect->fnSetHeight)((Frm().*fnRect->fnGetHeight)() - nBorder );
if( (Prt().*fnRect->fnGetHeight)() < 0 && !pPage->IsFtnPage() )
- bValidSize = sal_False;
+ mbValidSize = sal_False;
}
- if ( !bValidSize )
+ if ( !mbValidSize )
{
bool bGrow = pPage->IsFtnPage();
if( bGrow )
@@ -294,7 +294,7 @@ void SwFtnContFrm::Format( const SwBorderAttrs * )
}
}
}
- bValidSize = sal_True;
+ mbValidSize = sal_True;
}
}
/*************************************************************************
@@ -489,7 +489,7 @@ SwFtnFrm::SwFtnFrm( SwFrmFmt *pFmt, SwFrm* pSib, SwCntntFrm *pCnt, SwTxtFtn *pAt
// #i49383#
mbUnlockPosOfLowerObjs( true )
{
- nType = FRMC_FTN;
+ mnType = FRMC_FTN;
}
/*************************************************************************
diff --git a/sw/source/core/layout/hffrm.cxx b/sw/source/core/layout/hffrm.cxx
index 4d0df19..2b2b368 100644
--- a/sw/source/core/layout/hffrm.cxx
+++ b/sw/source/core/layout/hffrm.cxx
@@ -109,7 +109,7 @@ static void lcl_LayoutFrmEnsureMinHeight(SwLayoutFrm & rFrm,
SwHeadFootFrm::SwHeadFootFrm( SwFrmFmt * pFmt, SwFrm* pSib, sal_uInt16 nTypeIn)
: SwLayoutFrm( pFmt, pSib )
{
- nType = nTypeIn;
+ mnType = nTypeIn;
SetDerivedVert( sal_False );
const SwFmtCntnt &rCnt = pFmt->GetCntnt();
@@ -187,41 +187,41 @@ void SwHeadFootFrm::FormatPrt(SwTwips & nUL, const SwBorderAttrs * pAttrs)
// OD 23.01.2003 #106895# - add first parameter to <SwBorderAttrs::CalcRight(..)>
SwTwips nLR = pAttrs->CalcLeft( this ) + pAttrs->CalcRight( this );
- aPrt.Left(pAttrs->CalcLeft(this));
+ maPrt.Left(pAttrs->CalcLeft(this));
if (IsHeaderFrm())
- aPrt.Top(pAttrs->CalcTop());
+ maPrt.Top(pAttrs->CalcTop());
else
- aPrt.Top(nSpace);
+ maPrt.Top(nSpace);
- aPrt.Width(aFrm.Width() - nLR);
+ maPrt.Width(maFrm.Width() - nLR);
SwTwips nNewHeight;
- if (nUL < aFrm.Height())
- nNewHeight = aFrm.Height() - nUL;
+ if (nUL < maFrm.Height())
+ nNewHeight = maFrm.Height() - nUL;
else
nNewHeight = 0;
- aPrt.Height(nNewHeight);
+ maPrt.Height(nNewHeight);
}
else
{
// Set position
- aPrt.Left( pAttrs->CalcLeft( this ) );
- aPrt.Top ( pAttrs->CalcTop() );
+ maPrt.Left( pAttrs->CalcLeft( this ) );
+ maPrt.Top ( pAttrs->CalcTop() );
// Set sizes - the sizes are given by the surrounding Frm, just
// subtract the borders.
// OD 23.01.2003 #106895# - add first parameter to <SwBorderAttrs::CalcRight(..)>
SwTwips nLR = pAttrs->CalcLeft( this ) + pAttrs->CalcRight( this );
- aPrt.Width ( aFrm.Width() - nLR );
- aPrt.Height( aFrm.Height()- nUL );
+ maPrt.Width ( maFrm.Width() - nLR );
+ maPrt.Height( maFrm.Height()- nUL );
}
- bValidPrtArea = sal_True;
+ mbValidPrtArea = sal_True;
}
void SwHeadFootFrm::FormatSize(SwTwips nUL, const SwBorderAttrs * pAttrs)
@@ -230,7 +230,7 @@ void SwHeadFootFrm::FormatSize(SwTwips nUL, const SwBorderAttrs * pAttrs)
{
if( !IsColLocked() )
{
- bValidSize = bValidPrtArea = sal_True;
+ mbValidSize = mbValidPrtArea = sal_True;
const SwTwips nBorder = nUL;
SwTwips nMinHeight = lcl_GetFrmMinHeight(*this);
@@ -383,11 +383,11 @@ void SwHeadFootFrm::FormatSize(SwTwips nUL, const SwBorderAttrs * pAttrs)
Prt().SSize().Height() = Frm().Height() - nBorder;
}
}
- bValidSize = bValidPrtArea = sal_True;
+ mbValidSize = mbValidPrtArea = sal_True;
} while( nRemaining<=nMaxHeight && nOldHeight!=Prt().Height() );
ColUnlock();
}
- bValidSize = bValidPrtArea = sal_True;
+ mbValidSize = mbValidPrtArea = sal_True;
}
else //if ( GetType() & 0x0018 )
{
@@ -395,9 +395,9 @@ void SwHeadFootFrm::FormatSize(SwTwips nUL, const SwBorderAttrs * pAttrs)
{
if ( Frm().Height() != pAttrs->GetSize().Height() )
ChgSize( Size( Frm().Width(), pAttrs->GetSize().Height()));
- bValidSize = sal_True;
+ mbValidSize = sal_True;
MakePos();
- } while ( !bValidSize );
+ } while ( !mbValidSize );
}
}
@@ -405,7 +405,7 @@ void SwHeadFootFrm::Format(const SwBorderAttrs * pAttrs)
{
OSL_ENSURE( pAttrs, "SwFooterFrm::Format, pAttrs is 0." );
- if ( bValidPrtArea && bValidSize )
+ if ( mbValidPrtArea && mbValidSize )
return;
if ( ! GetEatSpacing() && IsHeaderFrm())
@@ -418,10 +418,10 @@ void SwHeadFootFrm::Format(const SwBorderAttrs * pAttrs)
long nUL = pAttrs->CalcTop() + pAttrs->CalcBottom();
- if ( !bValidPrtArea )
+ if ( !mbValidPrtArea )
FormatPrt(nUL, pAttrs);
- if ( !bValidSize )
+ if ( !mbValidSize )
FormatSize(nUL, pAttrs);
}
}
@@ -455,9 +455,9 @@ SwTwips SwHeadFootFrm::GrowFrm( SwTwips nDist, sal_Bool bTst, sal_Bool bInfo )
/* calculate maximum eatable spacing */
if (IsHeaderFrm())
- nMaxEat = aFrm.Height() - aPrt.Top() - aPrt.Height() - pAttrs->CalcBottomLine();
+ nMaxEat = maFrm.Height() - maPrt.Top() - maPrt.Height() - pAttrs->CalcBottomLine();
else
- nMaxEat = aPrt.Top() - pAttrs->CalcTopLine();
+ nMaxEat = maPrt.Top() - pAttrs->CalcTopLine();
delete pAccess;
@@ -488,8 +488,8 @@ SwTwips SwHeadFootFrm::GrowFrm( SwTwips nDist, sal_Bool bTst, sal_Bool bInfo )
{
if (! IsHeaderFrm())
{
- aPrt.Top(aPrt.Top() - nEat);
- aPrt.Height(aPrt.Height() - nEat);
+ maPrt.Top(maPrt.Top() - nEat);
+ maPrt.Height(maPrt.Height() - nEat);
}
InvalidateAll();
@@ -595,7 +595,7 @@ SwTwips SwHeadFootFrm::ShrinkFrm( SwTwips nDist, sal_Bool bTst, sal_Bool bInfo )
SwTwips nShrink = nRest;
/* calculate maximum shrinking */
- SwTwips nMaxShrink = aPrt.Height() - nMinPrtHeight;
+ SwTwips nMaxShrink = maPrt.Height() - nMinPrtHeight;
/* shrink no more than maximum shrinking */
if (nShrink > nMaxShrink)
@@ -608,8 +608,8 @@ SwTwips SwHeadFootFrm::ShrinkFrm( SwTwips nDist, sal_Bool bTst, sal_Bool bInfo )
{
if (! IsHeaderFrm() )
{
- aPrt.Top(aPrt.Top() + nShrink);
- aPrt.Height(aPrt.Height() - nShrink);
+ maPrt.Top(maPrt.Top() + nShrink);
+ maPrt.Height(maPrt.Height() - nShrink);
}
InvalidateAll();
diff --git a/sw/source/core/layout/newfrm.cxx b/sw/source/core/layout/newfrm.cxx
index 9ea585b..5e41e2d 100644
--- a/sw/source/core/layout/newfrm.cxx
+++ b/sw/source/core/layout/newfrm.cxx
@@ -51,7 +51,7 @@ SwLayVout *SwRootFrm::pVout = 0;
bool SwRootFrm::bInPaint = false;
sal_Bool SwRootFrm::bNoVirDev = sal_False;
-SwCache *SwFrm::pCache = 0;
+SwCache *SwFrm::mpCache = 0;
long FirstMinusSecond( long nFirst, long nSecond )
{ return nFirst - nSecond; }
@@ -483,7 +483,7 @@ SwRootFrm::SwRootFrm( SwFrmFmt *pFmt, ViewShell * pSh ) :
nPhyPageNums( 0 ),
nAccessibleShells( 0 )
{
- nType = FRMC_ROOT;
+ mnType = FRMC_ROOT;
bIdleFormat = bTurboAllowed = bAssertFlyPages = bIsNewLayout = sal_True;
bCheckSuperfluous = bBrowseWidthValid = sal_False;
setRootFrm( this );
diff --git a/sw/source/core/layout/pagechg.cxx b/sw/source/core/layout/pagechg.cxx
index 54b2f22..949d13f 100644
--- a/sw/source/core/layout/pagechg.cxx
+++ b/sw/source/core/layout/pagechg.cxx
@@ -82,7 +82,7 @@ using namespace ::com::sun::star;
SwBodyFrm::SwBodyFrm( SwFrmFmt *pFmt, SwFrm* pSib ):
SwLayoutFrm( pFmt, pSib )
{
- nType = FRMC_BODY;
+ mnType = FRMC_BODY;
}
/*************************************************************************
@@ -99,7 +99,7 @@ void SwBodyFrm::Format( const SwBorderAttrs * )
//Vorsicht ist die Mutter der Robustheit).
//Die PrtArea ist stets so gross wie der Frm itself.
- if ( !bValidSize )
+ if ( !mbValidSize )
{
SwTwips nHeight = GetUpper()->Prt().Height();
SwTwips nWidth = GetUpper()->Prt().Width();
@@ -173,7 +173,7 @@ void SwBodyFrm::Format( const SwBorderAttrs * )
Prt().Height( Frm().Height() );
Prt().Width( Frm().Width() );
}
- bValidSize = bValidPrtArea = sal_True;
+ mbValidSize = mbValidPrtArea = sal_True;
}
void SwBodyFrm::Paint( const SwRect& rRect, const SwPrintData* ) const
@@ -218,7 +218,7 @@ SwPageFrm::SwPageFrm( SwFrmFmt *pFmt, SwFrm* pSib, SwPageDesc *pPgDsc ) :
bHasGrid = sal_False;
SetMaxFtnHeight( pPgDsc->GetFtnInfo().GetHeight() ?
pPgDsc->GetFtnInfo().GetHeight() : LONG_MAX ),
- nType = FRMC_PAGE;
+ mnType = FRMC_PAGE;
bInvalidLayout = bInvalidCntnt = bInvalidSpelling = bInvalidSmartTags = bInvalidAutoCmplWrds = bInvalidWordCount = sal_True;
bInvalidFlyLayout = bInvalidFlyCntnt = bInvalidFlyInCnt = bFtnPage = bEndNotePage = sal_False;
@@ -352,8 +352,8 @@ void SwPageFrm::CheckDirection( sal_Bool bVert )
if( FRMDIR_HORI_LEFT_TOP == nDir || FRMDIR_HORI_RIGHT_TOP == nDir )
{
//Badaa: 2008-04-18 * Support for Classical Mongolian Script (SCMS) joint with Jiayanmin
- bVertLR = 0;
- bVertical = 0;
+ mbVertLR = 0;
+ mbVertical = 0;
}
else
{
@@ -361,30 +361,30 @@ void SwPageFrm::CheckDirection( sal_Bool bVert )
if( pSh && pSh->GetViewOptions()->getBrowseMode() )
{
//Badaa: 2008-04-18 * Support for Classical Mongolian Script (SCMS) joint with Jiayanmin
- bVertLR = 0;
- bVertical = 0;
+ mbVertLR = 0;
+ mbVertical = 0;
}
else
{
- bVertical = 1;
+ mbVertical = 1;
//Badaa: 2008-04-18 * Support for Classical Mongolian Script (SCMS) joint with Jiayanmin
if(FRMDIR_VERT_TOP_RIGHT == nDir)
- bVertLR = 0;
+ mbVertLR = 0;
else if(FRMDIR_VERT_TOP_LEFT==nDir)
- bVertLR = 1;
+ mbVertLR = 1;
}
}
- bReverse = 0;
- bInvalidVert = 0;
+ mbReverse = 0;
+ mbInvalidVert = 0;
}
else
{
if( FRMDIR_HORI_RIGHT_TOP == nDir )
- bRightToLeft = 1;
+ mbRightToLeft = 1;
else
- bRightToLeft = 0;
- bInvalidR2L = 0;
+ mbRightToLeft = 0;
+ mbInvalidR2L = 0;
}
}
@@ -642,7 +642,7 @@ void SwPageFrm::_UpdateAttr( const SfxPoolItem *pOld, const SfxPoolItem *pNew,
ViewShell *pSh = getRootFrm()->GetCurrShell();
if( pSh && pSh->GetViewOptions()->getBrowseMode() )
{
- bValidSize = sal_False;
+ mbValidSize = sal_False;
// OD 28.10.2002 #97265# - Don't call <SwPageFrm::MakeAll()>
// Calculation of the page is not necessary, because its size is
// is invalidated here and further invalidation is done in the
@@ -1691,7 +1691,7 @@ Size SwRootFrm::ChgSize( const Size& aNewSize )
{
Frm().SSize() = aNewSize;
_InvalidatePrt();
- bFixSize = sal_False;
+ mbFixSize = sal_False;
return Frm().SSize();
}
@@ -1702,18 +1702,18 @@ Size SwRootFrm::ChgSize( const Size& aNewSize )
|*************************************************************************/
void SwRootFrm::MakeAll()
{
- if ( !bValidPos )
- { bValidPos = sal_True;
- aFrm.Pos().X() = aFrm.Pos().Y() = DOCUMENTBORDER;
+ if ( !mbValidPos )
+ { mbValidPos = sal_True;
+ maFrm.Pos().X() = maFrm.Pos().Y() = DOCUMENTBORDER;
}
- if ( !bValidPrtArea )
- { bValidPrtArea = sal_True;
- aPrt.Pos().X() = aPrt.Pos().Y() = 0;
- aPrt.SSize( aFrm.SSize() );
+ if ( !mbValidPrtArea )
+ { mbValidPrtArea = sal_True;
+ maPrt.Pos().X() = maPrt.Pos().Y() = 0;
+ maPrt.SSize( maFrm.SSize() );
}
- if ( !bValidSize )
+ if ( !mbValidSize )
//SSize wird von den Seiten (Cut/Paste) eingestellt.
- bValidSize = sal_True;
+ mbValidSize = sal_True;
}
/*************************************************************************
diff --git a/sw/source/core/layout/sectfrm.cxx b/sw/source/core/layout/sectfrm.cxx
index ade9a9d..3fc12ae 100644
--- a/sw/source/core/layout/sectfrm.cxx
+++ b/sw/source/core/layout/sectfrm.cxx
@@ -70,7 +70,7 @@ SwSectionFrm::SwSectionFrm( SwSection &rSect, SwFrm* pSib )
, bOwnFtnNum(false)
, bFtnLock(false)
{
- nType = FRMC_SECTION;
+ mnType = FRMC_SECTION;
CalcFtnAtEndFlag();
CalcEndAtEndFlag();
@@ -86,7 +86,7 @@ SwSectionFrm::SwSectionFrm( SwSectionFrm &rSect, sal_Bool bMaster ) :
bOwnFtnNum( false ),
bFtnLock( false )
{
- nType = FRMC_SECTION;
+ mnType = FRMC_SECTION;
PROTOCOL( this, PROT_SECTION, bMaster ? ACT_CREATE_MASTER : ACT_CREATE_FOLLOW, &rSect )
@@ -749,7 +749,7 @@ void SwSectionFrm::MakeAll()
#ifdef DBG_UTIL
OSL_ENSURE( getRootFrm()->IsInDelList( this ), "SectionFrm without Section" );
#endif
- if( !bValidPos )
+ if( !mbValidPos )
{
if( GetUpper() )
{
@@ -757,7 +757,7 @@ void SwSectionFrm::MakeAll()
(this->*fnRect->fnMakePos)( GetUpper(), GetPrev(), sal_False );
}
}
- bValidSize = bValidPos = bValidPrtArea = sal_True;
+ mbValidSize = mbValidPos = mbValidPrtArea = sal_True;
return;
}
LockJoin(); // I don't let myself to be destroyed on the way
@@ -787,8 +787,8 @@ void SwSectionFrm::MakeAll()
// A section with Follow uses all the space until the lower edge of the
// Upper. If it moves, its size can grow or decrease...
- if( !bValidPos && ToMaximize( sal_False ) )
- bValidSize = sal_False;
+ if( !mbValidPos && ToMaximize( sal_False ) )
+ mbValidSize = sal_False;
#if OSL_DEBUG_LEVEL > 1
const SwFmtCol &rCol = GetFmt()->GetCol();
@@ -1120,7 +1120,7 @@ void SwSectionFrm::SimpleFormat()
// assure notifications on position changes.
const SwLayNotify aNotify( this );
(this->*fnRect->fnMakePos)( GetUpper(), GetPrev(), sal_False );
- bValidPos = sal_True;
+ mbValidPos = sal_True;
}
SwTwips nDeadLine = (GetUpper()->*fnRect->fnGetPrtBottom)();
// OD 22.10.2002 #97265# - call always method <lcl_ColumnRefresh(..)>, in
@@ -1288,14 +1288,14 @@ void SwSectionFrm::Format( const SwBorderAttrs *pAttr )
#ifdef DBG_UTIL
OSL_ENSURE( getRootFrm()->IsInDelList( this ), "SectionFrm without Section" );
#endif
- bValidSize = bValidPos = bValidPrtArea = sal_True;
+ mbValidSize = mbValidPos = mbValidPrtArea = sal_True;
return;
}
SWRECTFN( this )
- if ( !bValidPrtArea )
+ if ( !mbValidPrtArea )
{
PROTOCOL( this, PROT_PRTAREA, 0, 0 )
- bValidPrtArea = sal_True;
+ mbValidPrtArea = sal_True;
SwTwips nUpper = CalcUpperSpace();
// #109700# LRSpace for sections
@@ -1304,7 +1304,7 @@ void SwSectionFrm::Format( const SwBorderAttrs *pAttr )
if( nUpper != (this->*fnRect->fnGetTopMargin)() )
{
- bValidSize = sal_False;
+ mbValidSize = sal_False;
SwFrm* pOwn = ContainsAny();
if( pOwn )
pOwn->_InvalidatePos();
@@ -1312,14 +1312,14 @@ void SwSectionFrm::Format( const SwBorderAttrs *pAttr )
(this->*fnRect->fnSetYMargins)( nUpper, 0 );
}
- if ( !bValidSize )
+ if ( !mbValidSize )
{
PROTOCOL_ENTER( this, PROT_SIZE, 0, 0 )
const long nOldHeight = (Frm().*fnRect->fnGetHeight)();
sal_Bool bOldLock = IsColLocked();
ColLock();
- bValidSize = sal_True;
+ mbValidSize = sal_True;
// The size is only determined by the content, if the SectFrm does not have a
// Follow. Otherwise it fills (occupies) the Upper down to the lower edge.
@@ -1351,11 +1351,11 @@ void SwSectionFrm::Format( const SwBorderAttrs *pAttr )
if( GetUpper() )
{
long nWidth = (GetUpper()->Prt().*fnRect->fnGetWidth)();
- (aFrm.*fnRect->fnSetWidth)( nWidth );
+ (maFrm.*fnRect->fnSetWidth)( nWidth );
// #109700# LRSpace for sections
const SvxLRSpaceItem& rLRSpace = GetFmt()->GetLRSpace();
- (aPrt.*fnRect->fnSetWidth)( nWidth - rLRSpace.GetLeft() -
+ (maPrt.*fnRect->fnSetWidth)( nWidth - rLRSpace.GetLeft() -
rLRSpace.GetRight() );
// OD 15.10.2002 #103517# - allow grow in online layout
@@ -1364,7 +1364,7 @@ void SwSectionFrm::Format( const SwBorderAttrs *pAttr )
const ViewShell *pSh = getRootFrm()->GetCurrShell();
_CheckClipping( pSh && pSh->GetViewOptions()->getBrowseMode(), bMaximize );
bMaximize = ToMaximize( sal_False );
- bValidSize = sal_True;
+ mbValidSize = sal_True;
}
// Check the width of the columns and adjust if necessary
@@ -1492,7 +1492,7 @@ void SwSectionFrm::Format( const SwBorderAttrs *pAttr )
GetUpper()->Shrink( nDiff );
}
if( IsUndersized() )
- bValidPrtArea = sal_True;
+ mbValidPrtArea = sal_True;
}
}
@@ -2282,7 +2282,7 @@ SwFrm* SwFrm::_GetIndPrev() const
SwFrm* SwFrm::_GetIndNext()
{
- OSL_ENSURE( !pNext && IsInSct(), "Why?" );
+ OSL_ENSURE( !mpNext && IsInSct(), "Why?" );
SwFrm* pSct = GetUpper();
if( !pSct )
return NULL;
diff --git a/sw/source/core/layout/ssfrm.cxx b/sw/source/core/layout/ssfrm.cxx
index d166018..4ae962e 100644
--- a/sw/source/core/layout/ssfrm.cxx
+++ b/sw/source/core/layout/ssfrm.cxx
@@ -117,66 +117,66 @@ void SwFrm::MakeBelowPos( const SwFrm* pUp, const SwFrm* pPrv, sal_Bool bNotify
{
if( pPrv )
{
- aFrm.Pos( pPrv->Frm().Pos() );
- aFrm.Pos().Y() += pPrv->Frm().Height();
+ maFrm.Pos( pPrv->Frm().Pos() );
+ maFrm.Pos().Y() += pPrv->Frm().Height();
}
else
{
- aFrm.Pos( pUp->Frm().Pos() );
- aFrm.Pos() += pUp->Prt().Pos();
+ maFrm.Pos( pUp->Frm().Pos() );
+ maFrm.Pos() += pUp->Prt().Pos();
}
if( bNotify )
- aFrm.Pos().Y() += 1;
+ maFrm.Pos().Y() += 1;
}
void SwFrm::MakeUpperPos( const SwFrm* pUp, const SwFrm* pPrv, sal_Bool bNotify )
{
if( pPrv )
{
- aFrm.Pos( pPrv->Frm().Pos() );
- aFrm.Pos().Y() -= Frm().Height();
+ maFrm.Pos( pPrv->Frm().Pos() );
+ maFrm.Pos().Y() -= Frm().Height();
}
else
{
- aFrm.Pos( pUp->Frm().Pos() );
- aFrm.Pos() += pUp->Prt().Pos();
- aFrm.Pos().Y() += pUp->Prt().Height() - aFrm.Height();
+ maFrm.Pos( pUp->Frm().Pos() );
+ maFrm.Pos() += pUp->Prt().Pos();
+ maFrm.Pos().Y() += pUp->Prt().Height() - maFrm.Height();
}
if( bNotify )
- aFrm.Pos().Y() -= 1;
+ maFrm.Pos().Y() -= 1;
}
void SwFrm::MakeLeftPos( const SwFrm* pUp, const SwFrm* pPrv, sal_Bool bNotify )
{
if( pPrv )
{
- aFrm.Pos( pPrv->Frm().Pos() );
- aFrm.Pos().X() -= Frm().Width();
+ maFrm.Pos( pPrv->Frm().Pos() );
+ maFrm.Pos().X() -= Frm().Width();
}
else
{
- aFrm.Pos( pUp->Frm().Pos() );
- aFrm.Pos() += pUp->Prt().Pos();
- aFrm.Pos().X() += pUp->Prt().Width() - aFrm.Width();
+ maFrm.Pos( pUp->Frm().Pos() );
+ maFrm.Pos() += pUp->Prt().Pos();
+ maFrm.Pos().X() += pUp->Prt().Width() - maFrm.Width();
}
if( bNotify )
- aFrm.Pos().X() -= 1;
+ maFrm.Pos().X() -= 1;
}
void SwFrm::MakeRightPos( const SwFrm* pUp, const SwFrm* pPrv, sal_Bool bNotify )
{
if( pPrv )
{
- aFrm.Pos( pPrv->Frm().Pos() );
- aFrm.Pos().X() += pPrv->Frm().Width();
+ maFrm.Pos( pPrv->Frm().Pos() );
+ maFrm.Pos().X() += pPrv->Frm().Width();
}
else
{
- aFrm.Pos( pUp->Frm().Pos() );
- aFrm.Pos() += pUp->Prt().Pos();
+ maFrm.Pos( pUp->Frm().Pos() );
+ maFrm.Pos() += pUp->Prt().Pos();
}
if( bNotify )
... etc. - the rest is truncated
More information about the Libreoffice-commits
mailing list
diff --git a/sw/source/core/layout/findfrm.cxx b/sw/source/core/layout/findfrm.cxx
index b3b2fc1..50f6107 100644
--- a/sw/source/core/layout/findfrm.cxx
+++ b/sw/source/core/layout/findfrm.cxx
@@ -1343,27 +1343,27 @@ void SwFrm::SetInfFlags()
if ( !IsFlyFrm() && !GetUpper() ) //not yet pasted, no information available
return;
- bInfInvalid = bInfBody = bInfTab = bInfFly = bInfFtn = bInfSct = sal_False;
+ mbInfInvalid = mbInfBody = mbInfTab = mbInfFly = mbInfFtn = mbInfSct = sal_False;
SwFrm *pFrm = this;
if( IsFtnContFrm() )
- bInfFtn = sal_True;
+ mbInfFtn = sal_True;
do
{
- // bInfBody is only set in the page body, but not in the column body
- if ( pFrm->IsBodyFrm() && !bInfFtn && pFrm->GetUpper()
+ // mbInfBody is only set in the page body, but not in the column body
+ if ( pFrm->IsBodyFrm() && !mbInfFtn && pFrm->GetUpper()
&& pFrm->GetUpper()->IsPageFrm() )
- bInfBody = sal_True;
+ mbInfBody = sal_True;
else if ( pFrm->IsTabFrm() || pFrm->IsCellFrm() )
{
- bInfTab = sal_True;
+ mbInfTab = sal_True;
}
else if ( pFrm->IsFlyFrm() )
- bInfFly = sal_True;
+ mbInfFly = sal_True;
else if ( pFrm->IsSctFrm() )
- bInfSct = sal_True;
+ mbInfSct = sal_True;
else if ( pFrm->IsFtnFrm() )
- bInfFtn = sal_True;
+ mbInfFtn = sal_True;
pFrm = pFrm->GetUpper();
@@ -1383,7 +1383,7 @@ void SwFrm::SetDirFlags( sal_Bool bVert )
{
// OD 2004-01-21 #114969# - if derived, valid vertical flag only if
// vertical flag of upper/anchor is valid.
- if( bDerivedVert )
+ if( mbDerivedVert )
{
const SwFrm* pAsk = IsFlyFrm() ?
((SwFlyFrm*)this)->GetAnchorFrm() : GetUpper();
@@ -1392,13 +1392,13 @@ void SwFrm::SetDirFlags( sal_Bool bVert )
if( pAsk )
{
- bVertical = pAsk->IsVertical() ? 1 : 0;
- bReverse = pAsk->IsReverse() ? 1 : 0;
+ mbVertical = pAsk->IsVertical() ? 1 : 0;
+ mbReverse = pAsk->IsReverse() ? 1 : 0;
- bVertLR = pAsk->IsVertLR() ? 1 : 0;
+ mbVertLR = pAsk->IsVertLR() ? 1 : 0;
//Badaa: 2008-04-18 * Support for Classical Mongolian Script (SCMS) joint with Jiayanmin
- if ( !pAsk->bInvalidVert )
- bInvalidVert = sal_False;
+ if ( !pAsk->mbInvalidVert )
+ mbInvalidVert = sal_False;
}
}
else
@@ -1407,9 +1407,9 @@ void SwFrm::SetDirFlags( sal_Bool bVert )
else
{
sal_Bool bInv = 0;
- if( !bDerivedR2L ) // CheckDirection is able to set bDerivedR2L!
+ if( !mbDerivedR2L ) // CheckDirection is able to set bDerivedR2L!
CheckDirection( bVert );
- if( bDerivedR2L )
+ if( mbDerivedR2L )
{
const SwFrm* pAsk = IsFlyFrm() ?
((SwFlyFrm*)this)->GetAnchorFrm() : GetUpper();
@@ -1417,11 +1417,11 @@ void SwFrm::SetDirFlags( sal_Bool bVert )
OSL_ENSURE( pAsk != this, "Oops! Stack overflow is about to happen" );
if( pAsk )
- bRightToLeft = pAsk->IsRightToLeft() ? 1 : 0;
- if( !pAsk || pAsk->bInvalidR2L )
- bInv = bInvalidR2L;
+ mbRightToLeft = pAsk->IsRightToLeft() ? 1 : 0;
+ if( !pAsk || pAsk->mbInvalidR2L )
+ bInv = mbInvalidR2L;
}
- bInvalidR2L = bInv;
+ mbInvalidR2L = bInv;
}
}